"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtSql import *
import enum


class QSqlQuery(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qsqlquery.html

    **Detailed Description**

    QSqlQuery encapsulates the functionality involved in creating, navigating
    and retrieving data from SQL queries which are executed on a
    **QSqlDatabase** . It can be used to execute DML (data manipulation
    language) statements, such as `SELECT`, `INSERT`, `UPDATE` and `DELETE`, as
    well as DDL (data definition language) statements, such as `CREATE` `TABLE`.
    It can also be used to execute database-specific commands which are not
    standard SQL (e.g. `SET DATESTYLE=ISO` for PostgreSQL).

    Successfully executed SQL statements set the query's state to active so that
    **isActive** () returns `true`. Otherwise the query's state is set to
    inactive. In either case, when executing a new SQL statement, the query is
    positioned on an invalid record. An active query must be navigated to a
    valid record (so that **isValid** () returns `true`) before values can be
    retrieved.

    For some databases, if an active query that is a `SELECT` statement exists
    when you call **commit** () or **rollback** (), the commit or rollback will
    fail. See **isActive** () for details.

    Navigating records is performed with the following functions:

    * **next** ()
      * **previous** ()
      * **first** ()
      * **last** ()
      *
    **seek** ()

    These functions allow the programmer to move forward, backward or
    arbitrarily through the records returned by the query. If you only need to
    move forward through the results (e.g., by using **next** ()), you can use
    **setForwardOnly** (), which will save a significant amount of memory
    overhead and improve performance on some databases. Once an active query is
    positioned on a valid record, data can be retrieved using **value** (). All
    data is transferred from the SQL backend using QVariants.

    For example:

    **QSqlQuery**  query("SELECT country FROM artist");
            while
    (query.next()) {
                **QString**  country =
    query.value(0).toString();
                doSomething(country);
            }

    To access the data returned by a query, use value(int). Each field in the
    data returned by a `SELECT` statement is accessed by passing the field's
    position in the statement, starting from 0. This makes using `SELECT *`
    queries inadvisable because the order of the fields returned is
    indeterminate.

    For the sake of efficiency, there are no functions to access a field by name
    (unless you use prepared queries with names, as explained below). To convert
    a field name into an index, use **record** ().**indexOf** (), for example:

    **QSqlQuery**  query("SELECT * FROM artist");
            int fieldNo =
    query.record().indexOf("country");
            while (query.next()) {
    **QString**  country = query.value(fieldNo).toString();
    doSomething(country);
            }

    QSqlQuery supports prepared query execution and the binding of parameter
    values to placeholders. Some databases don't support these features, so for
    those, Qt emulates the required functionality. For example, the Oracle and
    ODBC drivers have proper prepared query support, and Qt makes use of it; but
    for databases that don't have this support, Qt implements the feature
    itself, e.g. by replacing placeholders with actual values when a query is
    executed. Use **numRowsAffected** () to find out how many rows were affected
    by a non-`SELECT` query, and **size** () to find how many were retrieved by
    a `SELECT`.

    Oracle databases identify placeholders by using a colon-name syntax, e.g
    `:name`. ODBC simply uses `?` characters. Qt supports both syntaxes, with
    the restriction that you can't mix them in the same query.

    You can retrieve the values of all the fields in a single variable using
    **boundValues** ().

    **Note:** Not all SQL operations support binding values. Refer to your
    database system's documentation to check their availability.

    **Approaches to Binding Values**

    Below we present the same example using each of the four different binding
    approaches, as well as one example of binding values to a stored procedure.

    **Named binding using named placeholders:**

    **QSqlQuery**  query;
            query.prepare("INSERT INTO person (id,
    forename, surname) "
                          "VALUES (:id, :forename,
    :surname)");
            query.bindValue(":id", 1001);
    query.bindValue(":forename", "Bart");
            query.bindValue(":surname",
    "Simpson");
            query.exec();

    **Positional binding using named placeholders:**

    **QSqlQuery**  query;
            query.prepare("INSERT INTO person (id,
    forename, surname) "
                          "VALUES (:id, :forename,
    :surname)");
            query.bindValue(0, 1001);
            query.bindValue(1,
    "Bart");
            query.bindValue(2, "Simpson");
            query.exec();

    **Binding values using positional placeholders (version 1):**

    **QSqlQuery**  query;
            query.prepare("INSERT INTO person (id,
    forename, surname) "
                          "VALUES (?, ?, ?)");
    query.bindValue(0, 1001);
            query.bindValue(1, "Bart");
    query.bindValue(2, "Simpson");
            query.exec();

    **Binding values using positional placeholders (version 2):**

    **QSqlQuery**  query;
            query.prepare("INSERT INTO person (id,
    forename, surname) "
                          "VALUES (?, ?, ?)");
    query.addBindValue(1001);
            query.addBindValue("Bart");
    query.addBindValue("Simpson");
            query.exec();

    **Binding values to a stored procedure:**

    This code calls a stored procedure called `AsciiToInt()`, passing it a
    character through its in parameter, and taking its result in the out
    parameter.

    **QSqlQuery**  query;
            query.prepare("CALL AsciiToInt(?, ?)");
    query.bindValue(0, "A");
            query.bindValue(1, 0, QSql::Out);
    query.exec();
            int i = query.boundValue(1).toInt(); // i is 65

    Note that unbound parameters will retain their values.

    Stored procedures that uses the return statement to return values, or return
    multiple result sets, are not fully supported. For specific details see
    **SQL Database Drivers** .

    **Warning:** You must load the SQL driver and open the connection before a
    QSqlQuery is created. Also, the connection must remain open while the query
    exists; otherwise, the behavior of QSqlQuery is undefined.

    **See also** **QSqlDatabase** , **QSqlQueryModel** , **QSqlTableModel** ,
    and **QVariant** .
    """

    class BatchExecutionMode(enum.Enum):
        ValuesAsRows: QSqlQuery = ...
        ValuesAsColumns: QSqlQuery = ...

    @typing.overload
    def __init__(self, db: QSqlDatabase) -> None:
        """
        https://doc.qt.io/qt-6/qsqlquery.html#QSqlQuery

        **QSqlQuery::QSqlQuery(QSqlResult * result )**

        Constructs a QSqlQuery object which uses the **QSqlResult**  **result**
        to communicate with a database.
        """
        ...

    @typing.overload
    def __init__(self, query: str = ..., db: QSqlDatabase = ...) -> None:
        """
        https://doc.qt.io/qt-6/qsqlquery.html#QSqlQuery-1

        **QSqlQuery::QSqlQuery(const QString & query = QString(), const
        QSqlDatabase & db = QSqlDatabase())**

        Constructs a QSqlQuery object using the SQL **query** and the database
        **db**. If **db** is not specified, or is invalid, the application's
        default database is used. If **query** is not an empty string, it will
        be executed.

        **See also** **QSqlDatabase** .
        """
        ...

    @typing.overload
    def __init__(self, r: "QSqlResult") -> None:
        """
        https://doc.qt.io/qt-6/qsqlquery.html#QSqlQuery-2

        **QSqlQuery::QSqlQuery(const QSqlDatabase & db )**

        Constructs a QSqlQuery object using the database **db**. If **db** is
        invalid, the application's default database will be used.

        **See also** **QSqlDatabase** .
        """
        ...

    @typing.overload
    def __init__(self, other: "QSqlQuery") -> None:
        """
        https://doc.qt.io/qt-6/qsqlquery.html#QSqlQuery-4

        **[since 6.2] QSqlQuery::QSqlQuery(QSqlQuery && other )**

        Move-constructs a QSqlQuery from **other**.

        This function was introduced in Qt 6.2.
        """
        ...

    def swap(self, other: "QSqlQuery") -> None:
        """
        https://doc.qt.io/qt-6/qsqlquery.html#swap

        **[since 6.2] void QSqlQuery::swap(QSqlQuery & other )**

        Swaps **other** to this object. This operation is very fast and never
        fails.

        This function was introduced in Qt 6.2.
        """
        ...

    def nextResult(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlquery.html#nextResult

        **bool QSqlQuery::nextResult()**

        Discards the current result set and navigates to the next if available.

        Some databases are capable of returning multiple result sets for stored
        procedures or SQL batches (a query strings that contains multiple
        statements). If multiple result sets are available after executing a
        query this function can be used to navigate to the next result set(s).

        If a new result set is available this function will return true. The
        query will be repositioned on an **invalid** record in the new result
        set and must be navigated to a valid record before data values can be
        retrieved. If a new result set isn't available the function returns
        `false` and the query is set to inactive. In any case the old result set
        will be discarded.

        When one of the statements is a non-select statement a count of affected
        rows may be available instead of a result set.

        Note that some databases, i.e. Microsoft SQL Server, requires non-
        scrollable cursors when working with multiple result sets. Some
        databases may execute all statements at once while others may delay the
        execution until the result set is actually accessed, and some databases
        may have restrictions on which statements are allowed to be used in a
        SQL batch.

        **See also** **QSqlDriver::hasFeature** (), **setForwardOnly** (),
        **next** (), **isSelect** (), **numRowsAffected** (), **isActive** (),
        and **lastError** ().
        """
        ...

    def finish(self) -> None:
        """
        https://doc.qt.io/qt-6/qsqlquery.html#finish

        **void QSqlQuery::finish()**

        Instruct the database driver that no more data will be fetched from this
        query until it is re-executed. There is normally no need to call this
        function, but it may be helpful in order to free resources such as locks
        or cursors if you intend to re-use the query at a later time.

        Sets the query to inactive. Bound values retain their values.

        **See also** **prepare** (), **exec** (), and **isActive** ().
        """
        ...

    def numericalPrecisionPolicy(self) -> "QSql.NumericalPrecisionPolicy":
        """
        https://doc.qt.io/qt-6/qsqlquery.html#numericalPrecisionPolicy

        **QSql::NumericalPrecisionPolicy QSqlQuery::numericalPrecisionPolicy()
        const**

        Returns the current precision policy.

        **See also** **QSql::NumericalPrecisionPolicy**  and
        **setNumericalPrecisionPolicy** ().
        """
        ...

    def setNumericalPrecisionPolicy(
        self, precisionPolicy: "QSql.NumericalPrecisionPolicy"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsqlquery.html#setNumericalPrecisionPolicy

        **void
        QSqlQuery::setNumericalPrecisionPolicy(QSql::NumericalPrecisionPolicy
        precisionPolicy )**

        Instruct the database driver to return numerical values with a precision
        specified by **precisionPolicy**.

        The Oracle driver, for example, can retrieve numerical values as strings
        to prevent the loss of precision. If high precision doesn't matter, use
        this method to increase execution speed by bypassing string conversions.

        Note: Drivers that don't support fetching numerical values with low
        precision will ignore the precision policy. You can use
        **QSqlDriver::hasFeature** () to find out whether a driver supports this
        feature.

        Note: Setting the precision policy doesn't affect the currently active
        query. Call **exec** (QString) or **prepare** () in order to activate
        the policy.

        **See also** **QSql::NumericalPrecisionPolicy**  and
        **numericalPrecisionPolicy** ().
        """
        ...

    def lastInsertId(self) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qsqlquery.html#lastInsertId

        **QVariant QSqlQuery::lastInsertId() const**

        Returns the object ID of the most recent inserted row if the database
        supports it. An invalid **QVariant**  will be returned if the query did
        not insert any value or if the database does not report the id back. If
        more than one row was touched by the insert, the behavior is undefined.

        For MySQL databases the row's auto-increment field will be returned.

        **Note:** For this function to work in PSQL, the table table must
        contain OIDs, which may not have been created by default. Check the
        `default_with_oids` configuration variable to be sure.

        **See also** **QSqlDriver::hasFeature** ().
        """
        ...

    def executedQuery(self) -> str:
        """
        https://doc.qt.io/qt-6/qsqlquery.html#executedQuery

        **QString QSqlQuery::executedQuery() const**

        Returns the last query that was successfully executed.

        In most cases this function returns the same string as **lastQuery** ().
        If a prepared query with placeholders is executed on a DBMS that does
        not support it, the preparation of this query is emulated. The
        placeholders in the original query are replaced with their bound values
        to form a new query. This function returns the modified query. It is
        mostly useful for debugging purposes.

        **See also** **lastQuery** ().
        """
        ...

    def boundValues(self) -> typing.List[typing.Any]:
        """
        https://doc.qt.io/qt-6/qsqlquery.html#boundValues

        **[since 6.0] QVariantList QSqlQuery::boundValues() const**

        Returns a list of bound values.

        The order of the list is in binding order, irrespective of whether named
        or positional binding is used.

        The bound values can be examined in the following way:

        QVariantList list = query.boundValues();
                for (int i = 0; i <
        list.size(); ++i)
                    cout << i << ": " <<
        list.at(i).toString().toUtf8().data() << "\\n";

        This function was introduced in Qt 6.0.

        **See also** **boundValue** (), **bindValue** (), and **addBindValue**
        ().
        """
        ...

    @typing.overload
    def boundValue(self, placeholder: str) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qsqlquery.html#boundValue

        **QVariant QSqlQuery::boundValue(const QString & placeholder ) const**

        Returns the value for the **placeholder**.

        **See also** **boundValues** (), **bindValue** (), and **addBindValue**
        ().
        """
        ...

    @typing.overload
    def boundValue(self, pos: int) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qsqlquery.html#boundValue-1

        **QVariant QSqlQuery::boundValue(int pos ) const**

        Returns the value for the placeholder at position **pos**.
        """
        ...

    def addBindValue(self, val: typing.Any, type: "QSql.ParamTypeFlag" = ...) -> None:
        """
        https://doc.qt.io/qt-6/qsqlquery.html#addBindValue

        **void QSqlQuery::addBindValue(const QVariant & val , QSql::ParamType
        paramType = QSql::In)**

        Adds the value **val** to the list of values when using positional value
        binding. The order of the addBindValue() calls determines which
        placeholder a value will be bound to in the prepared query. If
        **paramType** is **QSql::Out**  or **QSql::InOut** , the placeholder
        will be overwritten with data from the database after the **exec** ()
        call.

        To bind a NULL value, use a null **QVariant** ; for example, use
        `QVariant(QMetaType::QString)` if you are binding a string.

        **See also** **bindValue** (), **prepare** (), **exec** (),
        **boundValue** (), and **boundValues** ().
        """
        ...

    @typing.overload
    def bindValue(
        self, placeholder: str, val: typing.Any, type: "QSql.ParamTypeFlag" = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsqlquery.html#bindValue

        **void QSqlQuery::bindValue(const QString & placeholder , const QVariant
        & val , QSql::ParamType paramType = QSql::In)**

        Set the placeholder **placeholder** to be bound to value **val** in the
        prepared statement. Note that the placeholder mark (e.g `:`) must be
        included when specifying the placeholder name. If **paramType** is
        **QSql::Out**  or **QSql::InOut** , the placeholder will be overwritten
        with data from the database after the **exec** () call. In this case,
        sufficient space must be pre-allocated to store the result into.

        To bind a NULL value, use a null **QVariant** ; for example, use
        `QVariant(QMetaType::QString)` if you are binding a string.

        **See also** **addBindValue** (), **prepare** (), **exec** (),
        **boundValue** (), and **boundValues** ().
        """
        ...

    @typing.overload
    def bindValue(
        self, pos: int, val: typing.Any, type: "QSql.ParamTypeFlag" = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsqlquery.html#bindValue-1

        **void QSqlQuery::bindValue(int pos , const QVariant & val ,
        QSql::ParamType paramType = QSql::In)**

        Set the placeholder in position **pos** to be bound to value **val** in
        the prepared statement. Field numbering starts at 0. If **paramType** is
        **QSql::Out**  or **QSql::InOut** , the placeholder will be overwritten
        with data from the database after the **exec** () call.
        """
        ...

    def prepare(self, query: str) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlquery.html#prepare

        **bool QSqlQuery::prepare(const QString & query )**

        Prepares the SQL query **query** for execution. Returns `true` if the
        query is prepared successfully; otherwise returns `false`.

        The query may contain placeholders for binding values. Both Oracle style
        colon-name (e.g., `:surname`), and ODBC style (`?`) placeholders are
        supported; but they cannot be mixed in the same query. See the
        **Detailed Description**  for examples.

        Portability notes: Some databases choose to delay preparing a query
        until it is executed the first time. In this case, preparing a
        syntactically wrong query succeeds, but every consecutive **exec** ()
        will fail. When the database does not support named placeholders
        directly, the placeholder can only contain characters in the range
        [a-zA-Z0-9**_** ].

        For SQLite, the query string can contain only one statement at a time.
        If more than one statement is given, the function returns `false`.

        Example:

        **QSqlQuery**  query;
                query.prepare("INSERT INTO person (id,
        forename, surname) "
                              "VALUES (:id, :forename,
        :surname)");
                query.bindValue(":id", 1001);
        query.bindValue(":forename", "Bart");
        query.bindValue(":surname", "Simpson");
                query.exec();

        **See also** **exec** (), **bindValue** (), and **addBindValue** ().
        """
        ...

    def execBatch(self, mode: "QSqlQuery.BatchExecutionMode" = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlquery.html#execBatch

        **bool QSqlQuery::execBatch(QSqlQuery::BatchExecutionMode mode =
        ValuesAsRows)**

        Executes a previously prepared SQL query in a batch. All the bound
        parameters have to be lists of variants. If the database doesn't support
        batch executions, the driver will simulate it using conventional
        **exec** () calls.

        Returns `true` if the query is executed successfully; otherwise returns
        `false`.

        Example:

        **QSqlQuery**  q;
            q.prepare("insert into myTable values (?, ?)");
        QVariantList ints;
            ints << 1 << 2 << 3 << 4;
        q.addBindValue(ints);

            QVariantList names;
            names << "Harald"
        << "Boris" << "Trond" << **QVariant** (**QMetaType** ::**QString** );
        q.addBindValue(names);

            if (!q.execBatch())
                **qDebug**
        () << q.lastError();

        The example above inserts four new rows into `myTable`:

        1  Harald
            2  Boris
            3  Trond
            4  NULL

        To bind NULL values, a null **QVariant**  of the relevant type has to be
        added to the bound QVariantList; for example,
        `QVariant(QMetaType::QString)` should be used if you are using strings.

        **Note:** Every bound QVariantList must contain the same amount of
        variants.

        **Note:** The type of the QVariants in a list must not change. For
        example, you cannot mix integer and string variants within a
        QVariantList.

        The **mode** parameter indicates how the bound QVariantList will be
        interpreted. If **mode** is `ValuesAsRows`, every variant within the
        QVariantList will be interpreted as a value for a new row.
        `ValuesAsColumns` is a special case for the Oracle driver. In this mode,
        every entry within a QVariantList will be interpreted as array-value for
        an IN or OUT value within a stored procedure. Note that this will only
        work if the IN or OUT value is a table-type consisting of only one
        column of a basic type, for example `TYPE myType IS TABLE OF VARCHAR(64)
        INDEX BY BINARY_INTEGER;`

        **See also** **prepare** (), **bindValue** (), and **addBindValue** ().
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qsqlquery.html#clear

        **void QSqlQuery::clear()**

        Clears the result set and releases any resources held by the query. Sets
        the query state to inactive. You should rarely if ever need to call this
        function.
        """
        ...

    def last(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlquery.html#last

        **bool QSqlQuery::last()**

        Retrieves the last record in the result, if available, and positions the
        query on the retrieved record. Note that the result must be in the
        **active**  state and **isSelect** () must return true before calling
        this function or it will do nothing and return false. Returns `true` if
        successful. If unsuccessful the query position is set to an invalid
        position and false is returned.

        **See also** **next** (), **previous** (), **first** (), **seek** (),
        **at** (), **isActive** (), and **isValid** ().
        """
        ...

    def first(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlquery.html#first

        **bool QSqlQuery::first()**

        Retrieves the first record in the result, if available, and positions
        the query on the retrieved record. Note that the result must be in the
        **active**  state and **isSelect** () must return true before calling
        this function or it will do nothing and return false. Returns `true` if
        successful. If unsuccessful the query position is set to an invalid
        position and false is returned.

        **See also** **next** (), **previous** (), **last** (), **seek** (),
        **at** (), **isActive** (), and **isValid** ().
        """
        ...

    def previous(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlquery.html#previous

        **bool QSqlQuery::previous()**

        Retrieves the previous record in the result, if available, and positions
        the query on the retrieved record. Note that the result must be in the
        **active**  state and **isSelect** () must return true before calling
        this function or it will do nothing and return false.

        The following rules apply:

        * If the result is currently located before the first record, there is
        no change and false is returned.
          * If the result is currently located
        after the last record, an attempt is made to retrieve the last record.
        * If the result is somewhere in the middle, an attempt is made to
        retrieve the previous record.

        If the record could not be retrieved, the result is positioned before
        the first record and false is returned. If the record is successfully
        retrieved, true is returned.

        **See also** **next** (), **first** (), **last** (), **seek** (), **at**
        (), **isActive** (), and **isValid** ().
        """
        ...

    def next(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlquery.html#next

        **bool QSqlQuery::next()**

        Retrieves the next record in the result, if available, and positions the
        query on the retrieved record. Note that the result must be in the
        **active**  state and **isSelect** () must return true before calling
        this function or it will do nothing and return false.

        The following rules apply:

        * If the result is currently located before the first record, e.g.
        immediately after a query is executed, an attempt is made to retrieve
        the first record.
          * If the result is currently located after the last
        record, there is no change and false is returned.
          * If the result is
        located somewhere in the middle, an attempt is made to retrieve the next
        record.

        If the record could not be retrieved, the result is positioned after the
        last record and false is returned. If the record is successfully
        retrieved, true is returned.

        **See also** **previous** (), **first** (), **last** (), **seek** (),
        **at** (), **isActive** (), and **isValid** ().
        """
        ...

    def seek(self, index: int, relative: bool = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlquery.html#seek

        **bool QSqlQuery::seek(int index , bool relative = false)**

        Retrieves the record at position **index** , if available, and positions
        the query on the retrieved record. The first record is at position 0.
        Note that the query must be in an **active**  state and **isSelect** ()
        must return true before calling this function.

        If **relative** is false (the default), the following rules apply:

        * If **index** is negative, the result is positioned before the first
        record and false is returned.
          * Otherwise, an attempt is made to move
        to the record at position **index**. If the record at position **index**
        could not be retrieved, the result is positioned after the last record
        and false is returned. If the record is successfully retrieved, true is
        returned.

        If **relative** is true, the following rules apply:

        * If the result is currently positioned before the first record and:
        * **index** is negative or zero, there is no change, and false is
        returned.
            * **index** is positive, an attempt is made to position
        the result at absolute position **index** \\- 1, following the sames rule
        for non relative seek, above.
          * If the result is currently positioned
        after the last record and:
            * **index** is positive or zero, there is
        no change, and false is returned.
            * **index** is negative, an
        attempt is made to position the result at **index** \\+ 1 relative
        position from last record, following the rule below.
          * If the result
        is currently located somewhere in the middle, and the relative offset
        **index** moves the result below zero, the result is positioned before
        the first record and false is returned.
          * Otherwise, an attempt is
        made to move to the record **index** records ahead of the current record
        (or **index** records behind the current record if **index** is
        negative). If the record at offset **index** could not be retrieved, the
        result is positioned after the last record if **index** >= 0, (or before
        the first record if **index** is negative), and false is returned. If
        the record is successfully retrieved, true is returned.

        **See also** **next** (), **previous** (), **first** (), **last** (),
        **at** (), **isActive** (), and **isValid** ().
        """
        ...

    @typing.overload
    def value(self, i: int) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qsqlquery.html#value

        **QVariant QSqlQuery::value(int index ) const**

        Returns the value of field **index** in the current record.

        The fields are numbered from left to right using the text of the
        `SELECT` statement, e.g. in

        SELECT forename, surname FROM people;

        field 0 is `forename` and field 1 is `surname`. Using `SELECT *` is not
        recommended because the order of the fields in the query is undefined.

        An invalid **QVariant**  is returned if field **index** does not exist,
        if the query is inactive, or if the query is positioned on an invalid
        record.

        **See also** **previous** (), **next** (), **first** (), **last** (),
        **seek** (), **isActive** (), and **isValid** ().
        """
        ...

    @typing.overload
    def value(self, name: str) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qsqlquery.html#value-1

        **QVariant QSqlQuery::value(const QString & name ) const**

        This is an overloaded function.

        Returns the value of the field called **name** in the current record. If
        field **name** does not exist an invalid variant is returned.

        This overload is less efficient than **value** ()
        """
        ...

    @typing.overload
    def exec(self, query: str) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlquery.html#exec

        **bool QSqlQuery::exec(const QString & query )**

        Executes the SQL in **query**. Returns `true` and sets the query state
        to **active**  if the query was successful; otherwise returns `false`.
        The **query** string must use syntax appropriate for the SQL database
        being queried (for example, standard SQL).

        After the query is executed, the query is positioned on an **invalid**
        record and must be navigated to a valid record before data values can be
        retrieved (for example, using **next** ()).

        Note that the last error for this query is reset when exec() is called.

        For SQLite, the query string can contain only one statement at a time.
        If more than one statement is given, the function returns `false`.

        Example:

        **QSqlQuery**  query;
                query.exec("INSERT INTO employee (id,
        name, salary) "
                           "VALUES (1001, 'Thad Beaumont',
        65000)");

        **See also** **isActive** (), **isValid** (), **next** (), **previous**
        (), **first** (), **last** (), and **seek** ().
        """
        ...

    @typing.overload
    def exec(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlquery.html#exec-1

        **bool QSqlQuery::exec()**

        Executes a previously prepared SQL query. Returns `true` if the query
        executed successfully; otherwise returns `false`.

        Note that the last error for this query is reset when exec() is called.

        **See also** **prepare** (), **bindValue** (), **addBindValue** (),
        **boundValue** (), and **boundValues** ().
        """
        ...

    def setForwardOnly(self, forward: bool) -> None:
        """
        https://doc.qt.io/qt-6/qsqlquery.html#setForwardOnly

        **void QSqlQuery::setForwardOnly(bool forward )**

        Sets forward only mode to **forward**. If **forward** is true, only
        **next** () and **seek** () with positive values, are allowed for
        navigating the results.

        Forward only mode can be (depending on the driver) more memory efficient
        since results do not need to be cached. It will also improve performance
        on some databases. For this to be true, you must call `setForwardOnly()`
        before the query is prepared or executed. Note that the constructor that
        takes a query and a database may execute the query.

        Forward only mode is off by default.

        Setting forward only to false is a suggestion to the database engine,
        which has the final say on whether a result set is forward only or
        scrollable. **isForwardOnly** () will always return the correct status
        of the result set.

        **Note:** Calling setForwardOnly after execution of the query will
        result in unexpected results at best, and crashes at worst.

        **Note:** To make sure the forward-only query completed successfully,
        the application should check **lastError** () for an error not only
        after executing the query, but also after navigating the query results.

        **Warning:** PostgreSQL: While navigating the query results in forward-
        only mode, do not execute any other SQL command on the same database
        connection. This will cause the query results to be lost.

        **See also** **isForwardOnly** (), **next** (), **seek** (), and
        **QSqlResult::setForwardOnly** ().
        """
        ...

    def record(self) -> QSqlRecord:
        """
        https://doc.qt.io/qt-6/qsqlquery.html#record

        **QSqlRecord QSqlQuery::record() const**

        Returns a **QSqlRecord**  containing the field information for the
        current query. If the query points to a valid row (**isValid** ()
        returns true), the record is populated with the row's values. An empty
        record is returned when there is no active query (**isActive** ()
        returns false).

        To retrieve values from a query, **value** () should be used since its
        index-based lookup is faster.

        In the following example, a `SELECT * FROM` query is executed. Since the
        order of the columns is not defined, **QSqlRecord::indexOf** () is used
        to obtain the index of a column.

        **QSqlQuery**  q("select * from employees");
            **QSqlRecord**  rec =
        q.record();

            **qDebug** () << "Number of columns: " <<
        rec.count();

            int nameCol = rec.indexOf("name"); // index of the
        field "name"
            while (q.next())
                **qDebug** () <<
        q.value(nameCol).toString(); // output all names

        **See also** **value** ().
        """
        ...

    def isForwardOnly(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlquery.html#isForwardOnly

        **bool QSqlQuery::isForwardOnly() const**

        Returns `true` if you can only scroll forward through a result set;
        otherwise returns `false`.

        **See also** **setForwardOnly** () and **next** ().
        """
        ...

    def result(self) -> "QSqlResult":
        """
        https://doc.qt.io/qt-6/qsqlquery.html#result

        **const QSqlResult *QSqlQuery::result() const**

        Returns the result associated with the query.
        """
        ...

    def driver(self) -> QSqlDriver:
        """
        https://doc.qt.io/qt-6/qsqlquery.html#driver

        **const QSqlDriver *QSqlQuery::driver() const**

        Returns the database driver associated with the query.
        """
        ...

    def size(self) -> int:
        """
        https://doc.qt.io/qt-6/qsqlquery.html#size

        **int QSqlQuery::size() const**

        Returns the size of the result (number of rows returned), or -1 if the
        size cannot be determined or if the database does not support reporting
        information about query sizes. Note that for non-`SELECT` statements
        (**isSelect** () returns `false`), size() will return -1. If the query
        is not active (**isActive** () returns `false`), -1 is returned.

        To determine the number of rows affected by a non-`SELECT` statement,
        use **numRowsAffected** ().

        **See also** **isActive** (), **numRowsAffected** (), and
        **QSqlDriver::hasFeature** ().
        """
        ...

    def isSelect(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlquery.html#isSelect

        **bool QSqlQuery::isSelect() const**

        Returns `true` if the current query is a `SELECT` statement; otherwise
        returns `false`.
        """
        ...

    def lastError(self) -> QSqlError:
        """
        https://doc.qt.io/qt-6/qsqlquery.html#lastError

        **QSqlError QSqlQuery::lastError() const**

        Returns error information about the last error (if any) that occurred
        with this query.

        **See also** **QSqlError**  and **QSqlDatabase::lastError** ().
        """
        ...

    def numRowsAffected(self) -> int:
        """
        https://doc.qt.io/qt-6/qsqlquery.html#numRowsAffected

        **int QSqlQuery::numRowsAffected() const**

        Returns the number of rows affected by the result's SQL statement, or -1
        if it cannot be determined. Note that for `SELECT` statements, the value
        is undefined; use **size** () instead. If the query is not **active** ,
        -1 is returned.

        **See also** **size** () and **QSqlDriver::hasFeature** ().
        """
        ...

    def lastQuery(self) -> str:
        """
        https://doc.qt.io/qt-6/qsqlquery.html#lastQuery

        **QString QSqlQuery::lastQuery() const**

        Returns the text of the current query being used, or an empty string if
        there is no current query text.

        **See also** **executedQuery** ().
        """
        ...

    def at(self) -> int:
        """
        https://doc.qt.io/qt-6/qsqlquery.html#at

        **int QSqlQuery::at() const**

        Returns the current internal position of the query. The first record is
        at position zero. If the position is invalid, the function returns
        **QSql::BeforeFirstRow**  or **QSql::AfterLastRow** , which are special
        negative values.

        **See also** **previous** (), **next** (), **first** (), **last** (),
        **seek** (), **isActive** (), and **isValid** ().
        """
        ...

    @typing.overload
    def isNull(self, field: int) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlquery.html#isNull

        **bool QSqlQuery::isNull(int field ) const**

        Returns `true` if the query is not **active** , the query is not
        positioned on a valid record, there is no such **field** , or the
        **field** is null; otherwise `false`. Note that for some drivers,
        isNull() will not return accurate information until after an attempt is
        made to retrieve data.

        **See also** **isActive** (), **isValid** (), and **value** ().
        """
        ...

    @typing.overload
    def isNull(self, name: str) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlquery.html#isNull-1

        **bool QSqlQuery::isNull(const QString & name ) const**

        This is an overloaded function.

        Returns `true` if there is no field with this **name** ; otherwise
        returns isNull(int index) for the corresponding field index.

        This overload is less efficient than **isNull** ()
        """
        ...

    def isActive(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlquery.html#isActive

        **bool QSqlQuery::isActive() const**

        Returns `true` if the query is **active**. An active **QSqlQuery**  is
        one that has been **exec()'d**  successfully but not yet finished with.
        When you are finished with an active query, you can make the query
        inactive by calling **finish** () or **clear** (), or you can delete the
        **QSqlQuery**  instance.

        **Note:** Of particular interest is an active query that is a `SELECT`
        statement. For some databases that support transactions, an active query
        that is a `SELECT` statement can cause a **commit** () or a **rollback**
        () to fail, so before committing or rolling back, you should make your
        active `SELECT` statement query inactive using one of the ways listed
        above.

        **See also** **isSelect** ().
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlquery.html#isValid

        **bool QSqlQuery::isValid() const**

        Returns `true` if the query is currently positioned on a valid record;
        otherwise returns `false`.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QStackedLayout(QLayout):
    """
    https://doc.qt.io/qt-6/qstackedlayout.html

    **Detailed Description**

    QStackedLayout can be used to create a user interface similar to the one
    provided by **QTabWidget** . There is also a convenience **QStackedWidget**
    class built on top of QStackedLayout.

    A QStackedLayout can be populated with a number of child widgets ("pages").
    For example:

    **QWidget**  *firstPageWidget = new **QWidget** ;
            **QWidget**
    *secondPageWidget = new **QWidget** ;
            **QWidget**  *thirdPageWidget
    = new **QWidget** ;

            **QStackedLayout**  *stackedLayout = new
    **QStackedLayout** ;
            stackedLayout->addWidget(firstPageWidget);
    stackedLayout->addWidget(secondPageWidget);
    stackedLayout->addWidget(thirdPageWidget);

            **QVBoxLayout**
    *mainLayout = new **QVBoxLayout** ;
    mainLayout->addLayout(stackedLayout);
            setLayout(mainLayout);

    QStackedLayout provides no intrinsic means for the user to switch page. This
    is typically done through a **QComboBox**  or a **QListWidget**  that stores
    the titles of the QStackedLayout's pages. For example:

    **QComboBox**  *pageComboBox = new **QComboBox** ;
    pageComboBox->addItem(tr("Page 1"));
            pageComboBox->addItem(tr("Page
    2"));
            pageComboBox->addItem(tr("Page 3"));
    connect(pageComboBox, &**QComboBox** ::activated,
    stackedLayout, &**QStackedLayout** ::setCurrentIndex);

    When populating a layout, the widgets are added to an internal list. The
    **indexOf** () function returns the index of a widget in that list. The
    widgets can either be added to the end of the list using the **addWidget**
    () function, or inserted at a given index using the **insertWidget** ()
    function. The **removeWidget** () function removes the widget at the given
    index from the layout. The number of widgets contained in the layout, can be
    obtained using the **count** () function.

    The **widget** () function returns the widget at a given index position. The
    index of the widget that is shown on screen is given by **currentIndex** ()
    and can be changed using **setCurrentIndex** (). In a similar manner, the
    currently shown widget can be retrieved using the **currentWidget** ()
    function, and altered using the **setCurrentWidget** () function.

    Whenever the current widget in the layout changes or a widget is removed
    from the layout, the **currentChanged** () and **widgetRemoved** () signals
    are emitted respectively.

    **See also** **QStackedWidget**  and **QTabWidget** .
    """

    class StackingMode(enum.Enum):
        StackOne: QStackedLayout = ...
        StackAll: QStackedLayout = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qstackedlayout.html#QStackedLayout

        **QStackedLayout::QStackedLayout()**

        Constructs a QStackedLayout with no parent.

        This QStackedLayout must be installed on a widget later on to become
        effective.

        **See also** **addWidget** () and **insertWidget** ().
        """
        ...

    @typing.overload
    def __init__(self, parent: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qstackedlayout.html#QStackedLayout-1

        **QStackedLayout::QStackedLayout(QWidget * parent )**

        Constructs a new QStackedLayout with the given **parent**.

        This layout will install itself on the **parent** widget and manage the
        geometry of its children.
        """
        ...

    @typing.overload
    def __init__(self, parentLayout: QLayout) -> None:
        """
        https://doc.qt.io/qt-6/qstackedlayout.html#QStackedLayout-2

        **QStackedLayout::QStackedLayout(QLayout * parentLayout )**

        Constructs a new QStackedLayout and inserts it into the given
        **parentLayout**.
        """
        ...

    def heightForWidth(self, width: int) -> int:
        """
        https://doc.qt.io/qt-6/qstackedlayout.html#heightForWidth

        **[override virtual] int QStackedLayout::heightForWidth(int width )
        const**

        Reimplements: **QLayoutItem::heightForWidth(int) const** .
        """
        ...

    def hasHeightForWidth(self) -> bool:
        """
        https://doc.qt.io/qt-6/qstackedlayout.html#hasHeightForWidth

        **[override virtual] bool QStackedLayout::hasHeightForWidth() const**

        Reimplements: **QLayoutItem::hasHeightForWidth() const** .
        """
        ...

    def setStackingMode(self, stackingMode: "QStackedLayout.StackingMode") -> None:
        """
        https://doc.qt.io/qt-6/qstackedlayout.html#stackingMode-prop

        **stackingMode : StackingMode**

        determines the way visibility of child widgets are handled.

        The default value is **StackOne** . Setting the property to **StackAll**
        allows you to make use of the layout for overlay widgets that do
        additional drawing on top of other widgets, for example, graphical
        editors.

        **Access functions:**

        QStackedLayout::StackingMode **stackingMode** () const
        void
        **setStackingMode** (QStackedLayout::StackingMode **stackingMode** )

        **Member Function Documentation**
        """
        ...

    def stackingMode(self) -> "QStackedLayout.StackingMode":
        """
        https://doc.qt.io/qt-6/qstackedlayout.html#stackingMode-prop

        **stackingMode : StackingMode**

        determines the way visibility of child widgets are handled.

        The default value is **StackOne** . Setting the property to **StackAll**
        allows you to make use of the layout for overlay widgets that do
        additional drawing on top of other widgets, for example, graphical
        editors.

        **Access functions:**

        QStackedLayout::StackingMode **stackingMode** () const
        void
        **setStackingMode** (QStackedLayout::StackingMode **stackingMode** )

        **Member Function Documentation**
        """
        ...

    def setCurrentWidget(self, w: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qstackedlayout.html#setCurrentWidget

        **[slot] void QStackedLayout::setCurrentWidget(QWidget * widget )**

        Sets the current widget to be the specified **widget**. The new current
        widget must already be contained in this stacked layout.

        **See also** **setCurrentIndex** () and **currentWidget** ().
        """
        ...

    def setCurrentIndex(self, index: int) -> None:
        """
        https://doc.qt.io/qt-6/qstackedlayout.html#currentIndex-prop

        **currentIndex : int**

        This property holds the index position of the widget that is visible

        The current index is -1 if there is no current widget.

        **Access functions:**

        int **currentIndex** () const
        void **setCurrentIndex** (int **index**
        )

        **Notifier signal:**

        void ****currentChanged** ** (int **index** )

        **See also** **currentWidget** () and **indexOf** ().
        """
        ...

    def setGeometry(self, rect: QtCore.QRect) -> None:
        """
        https://doc.qt.io/qt-6/qstackedlayout.html#setGeometry

        **[override virtual] void QStackedLayout::setGeometry(const QRect & rect
        )**

        Reimplements: **QLayout::setGeometry** (const QRect &r).
        """
        ...

    def takeAt(self, a0: int) -> QLayoutItem:
        """
        https://doc.qt.io/qt-6/qstackedlayout.html#takeAt

        **[override virtual] QLayoutItem *QStackedLayout::takeAt(int index )**

        Reimplements: **QLayout::takeAt** (int index).
        """
        ...

    def itemAt(self, a0: int) -> QLayoutItem:
        """
        https://doc.qt.io/qt-6/qstackedlayout.html#itemAt

        **[override virtual] QLayoutItem *QStackedLayout::itemAt(int index )
        const**

        Reimplements: **QLayout::itemAt(int index) const** .
        """
        ...

    def minimumSize(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qstackedlayout.html#minimumSize

        **[override virtual] QSize QStackedLayout::minimumSize() const**

        Reimplements: **QLayout::minimumSize() const** .
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qstackedlayout.html#sizeHint

        **[override virtual] QSize QStackedLayout::sizeHint() const**

        Reimplements: **QLayoutItem::sizeHint() const** .
        """
        ...

    def addItem(self, item: QLayoutItem) -> None:
        """
        https://doc.qt.io/qt-6/qstackedlayout.html#addItem

        **[override virtual] void QStackedLayout::addItem(QLayoutItem * item )**

        Reimplements: **QLayout::addItem** (QLayoutItem *item).
        """
        ...

    def count(self) -> int:
        """
        https://doc.qt.io/qt-6/qstackedlayout.html#count-prop

        **[read-only] count : const int**

        This property holds the number of widgets contained in the layout

        **Access functions:**

        virtual int **count** () const override

        **See also** **currentIndex** () and **widget** ().
        """
        ...

    def widget(self, a0: int) -> QWidget:
        """
        https://doc.qt.io/qt-6/qstackedlayout.html#widget

        **QWidget *QStackedLayout::widget(int index ) const**

        Returns the widget at the given **index** , or `nullptr` if there is no
        widget at the given position.

        **See also** **currentWidget** () and **indexOf** ().
        """
        ...

    def currentIndex(self) -> int:
        """
        https://doc.qt.io/qt-6/qstackedlayout.html#currentIndex-prop

        **currentIndex : int**

        This property holds the index position of the widget that is visible

        The current index is -1 if there is no current widget.

        **Access functions:**

        int **currentIndex** () const
        void **setCurrentIndex** (int **index**
        )

        **Notifier signal:**

        void ****currentChanged** ** (int **index** )

        **See also** **currentWidget** () and **indexOf** ().
        """
        ...

    def currentWidget(self) -> QWidget:
        """
        https://doc.qt.io/qt-6/qstackedlayout.html#currentWidget

        **QWidget *QStackedLayout::currentWidget() const**

        Returns the current widget, or `nullptr` if there are no widgets in this
        layout.

        **See also** **currentIndex** () and **setCurrentWidget** ().
        """
        ...

    def insertWidget(self, index: int, w: QWidget) -> int:
        """
        https://doc.qt.io/qt-6/qstackedlayout.html#insertWidget

        **int QStackedLayout::insertWidget(int index , QWidget * widget )**

        Inserts the given **widget** at the given **index** in this
        **QStackedLayout** . If **index** is out of range, the widget is
        appended (in which case it is the actual index of the **widget** that is
        returned).

        If the **QStackedLayout**  is empty before this function is called, the
        given **widget** becomes the current widget.

        Inserting a new widget at an index less than or equal to the current
        index will increment the current index, but keep the current widget.

        **See also** **addWidget** (), **removeWidget** (), and
        **setCurrentWidget** ().
        """
        ...

    def addWidget(self, w: QWidget) -> int:
        """
        https://doc.qt.io/qt-6/qstackedlayout.html#addWidget

        **int QStackedLayout::addWidget(QWidget * widget )**

        Adds the given **widget** to the end of this layout and returns the
        index position of the **widget**.

        If the **QStackedLayout**  is empty before this function is called, the
        given **widget** becomes the current widget.

        **See also** **insertWidget** (), **removeWidget** (), and
        **setCurrentWidget** ().
        """
        ...

    @property
    def currentChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qstackedlayout.html#currentChanged

        **[signal] void QStackedLayout::currentChanged(int index )**

        This signal is emitted whenever the current widget in the layout
        changes. The **index** specifies the index of the new current widget, or
        -1 if there isn't a new one (for example, if there are no widgets in the
        **QStackedLayout** )

        **Note:** Notifier signal for property **currentIndex** .

        **See also** **currentWidget** () and **setCurrentWidget** ().
        """
        ...

    @property
    def widgetRemoved(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qstackedlayout.html#widgetRemoved

        **[signal] void QStackedLayout::widgetRemoved(int index )**

        This signal is emitted whenever a widget is removed from the layout. The
        widget's **index** is passed as parameter.

        **See also** **removeWidget** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtDesigner import *


class QExtensionFactory(QtCore.QObject, QAbstractExtensionFactory):
    """
    https://doc.qt.io/qt-6/qextensionfactory.html

    **Detailed Description**

    In **Qt Designer** the extensions are not created until they are required.
    For that reason, when implementing a custom extension, you must also create
    a QExtensionFactory, i.e. a class that is able to make an instance of your
    extension, and register it using **Qt Designer** 's **extension manager** .

    The **QExtensionManager**  class provides extension management facilities
    for Qt Designer. When an extension is required, Qt Designer's **extension
    manager**  will run through all its registered factories calling
    **QExtensionFactory::createExtension** () for each until the first one that
    is able to create a requested extension for the selected object, is found.
    This factory will then make an instance of the extension.

    There are four available types of extensions in Qt Designer:
    **QDesignerContainerExtension**  , **QDesignerMemberSheetExtension** ,
    **QDesignerPropertySheetExtension**  and **QDesignerTaskMenuExtension** . Qt
    Designer's behavior is the same whether the requested extension is
    associated with a multi page container, a member sheet, a property sheet or
    a task menu.

    You can either create a new QExtensionFactory and reimplement the
    **QExtensionFactory::createExtension** () function. For example:

    **QObject**  *ANewExtensionFactory::createExtension(**QObject**  *object,
    const **QString**  &iid, **QObject**  *parent) const
                {
    if (iid != Q_TYPEID(**QDesignerContainerExtension** ))
    return 0;

                    if (MyCustomWidget *widget =
    qobject_cast<MyCustomWidget*>
                           (object))
    return new MyContainerExtension(widget, parent);

                    return
    0;
                }

    Or you can use an existing factory, expanding the
    **QExtensionFactory::createExtension** () function to make the factory able
    to create your extension as well. For example:

    **QObject**  *AGeneralExtensionFactory::createExtension(**QObject**
    *object,
                        const **QString**  &iid, **QObject**  *parent)
    const
                {
                    MyCustomWidget *widget =
    qobject_cast<MyCustomWidget*>(object);

                    if (widget &&
    (iid == Q_TYPEID(**QDesignerTaskMenuExtension** ))) {
    return new MyTaskMenuExtension(widget, parent);

                    } else
    if (widget && (iid == Q_TYPEID(**QDesignerContainerExtension** ))) {
    return new MyContainerExtension(widget, parent);

                    } else
    {
                        return 0;
                    }
                }

    For a complete example using the QExtensionFactory class, see the **Task
    Menu Extension example** . The example shows how to create a custom widget
    plugin for Qt Designer, and how to to use the **QDesignerTaskMenuExtension**
    class to add custom items to Qt Designer's task menu.

    **See also** **QExtensionManager**  and **QAbstractExtensionFactory** .
    """

    def __init__(self, parent: typing.Optional["QExtensionManager"] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qextensionfactory.html#QExtensionFactory

        **QExtensionFactory::QExtensionFactory(QExtensionManager * parent =
        nullptr)**

        Constructs an extension factory with the given **parent**.
        """
        ...

    def createExtension(
        self, object: QtCore.QObject, iid: str, parent: QtCore.QObject
    ) -> QtCore.QObject:
        """
        https://doc.qt.io/qt-6/qextensionfactory.html#createExtension

        **[virtual protected] QObject
        *QExtensionFactory::createExtension(QObject * object , const QString &
        iid , QObject * parent ) const**

        Creates an extension specified by **iid** for the given **object**. The
        extension object is created as a child of the specified **parent**.

        **See also** **extension** ().
        """
        ...

    def extensionManager(self) -> "QExtensionManager":
        """
        https://doc.qt.io/qt-6/qextensionfactory.html#extensionManager

        **QExtensionManager *QExtensionFactory::extensionManager() const**

        Returns the extension manager for the extension factory.
        """
        ...

    def extension(self, object: QtCore.QObject, iid: str) -> QtCore.QObject:
        """
        https://doc.qt.io/qt-6/qextensionfactory.html#extension

        **[override virtual] QObject *QExtensionFactory::extension(QObject *
        object , const QString & iid ) const**

        Reimplements: **QAbstractExtensionFactory::extension(QObject *object,
        const QString &iid) const** .

        Returns the extension specified by **iid** for the given **object**.

        **See also** **createExtension** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QAbstractItemView(QAbstractScrollArea):
    """
    https://doc.qt.io/qt-6/qabstractitemview.html

    **Detailed Description**

    QAbstractItemView class is the base class for every standard view that uses
    a **QAbstractItemModel** . QAbstractItemView is an abstract class and cannot
    itself be instantiated. It provides a standard interface for interoperating
    with models through the signals and slots mechanism, enabling subclasses to
    be kept up-to-date with changes to their models. This class provides
    standard support for keyboard and mouse navigation, viewport scrolling, item
    editing, and selections. The keyboard navigation implements this
    functionality:

    KeysFunctionality
    Arrow keysChanges the current item and selects it.
    Ctrl+Arrow keysChanges the current item but does not select it.
    Shift+Arrow keysChanges the current item and selects it. The previously
    selected item(s) is not deselected.
    Ctrl+SpaceToggles selection of the
    current item.
    Tab/BacktabChanges the current item to the next/previous
    item.
    Home/EndSelects the first/last item in the model.
    Page up/Page
    downScrolls the rows shown up/down by the number of visible rows in the
    view.
    Ctrl+ASelects all items in the model.

    Note that the above table assumes that the **selection mode**  allows the
    operations. For instance, you cannot select items if the selection mode is
    **QAbstractItemView::NoSelection** .

    The QAbstractItemView class is one of the **Model/View Classes**  and is
    part of Qt's **model/view framework** .

    The view classes that inherit QAbstractItemView only need to implement their
    own view-specific functionality, such as drawing items, returning the
    geometry of items, finding items, etc.

    QAbstractItemView provides common slots such as **edit** () and
    **setCurrentIndex** (). Many protected slots are also provided, including
    **dataChanged** (), **rowsInserted** (), **rowsAboutToBeRemoved** (),
    **selectionChanged** (), and **currentChanged** ().

    The root item is returned by **rootIndex** (), and the current item by
    **currentIndex** (). To make sure that an item is visible use **scrollTo**
    ().

    Some of QAbstractItemView's functions are concerned with scrolling, for
    example **setHorizontalScrollMode** () and **setVerticalScrollMode** (). To
    set the range of the scroll bars, you can, for example, reimplement the
    view's **resizeEvent** () function:

    void MyView::resizeEvent(**QResizeEvent**  *event) {
    horizontalScrollBar()->setRange(0, realWidth - width());
            ...
        }

    Note that the range is not updated until the widget is shown.

    Several other functions are concerned with selection control; for example
    **setSelectionMode** (), and **setSelectionBehavior** (). This class
    provides a default selection model to work with (**selectionModel** ()), but
    this can be replaced by using **setSelectionModel** () with an instance of
    **QItemSelectionModel** .

    For complete control over the display and editing of items you can specify a
    delegate with **setItemDelegate** ().

    QAbstractItemView provides a lot of protected functions. Some are concerned
    with editing, for example, **edit** (), and **commitData** (), whilst others
    are keyboard and mouse event handlers.

    **Note:** If you inherit QAbstractItemView and intend to update the contents
    of the viewport, you should use viewport->**update** () instead of
    **update** () as all painting operations take place on the viewport.

    **See also** **View Classes** , **Model/View Programming** ,
    **QAbstractItemModel** , and **Chart Example** .
    """

    class DropIndicatorPosition(enum.Enum):
        OnItem: QAbstractItemView = ...
        AboveItem: QAbstractItemView = ...
        BelowItem: QAbstractItemView = ...
        OnViewport: QAbstractItemView = ...

    class State(enum.Enum):
        NoState: QAbstractItemView = ...
        DraggingState: QAbstractItemView = ...
        DragSelectingState: QAbstractItemView = ...
        EditingState: QAbstractItemView = ...
        ExpandingState: QAbstractItemView = ...
        CollapsingState: QAbstractItemView = ...
        AnimatingState: QAbstractItemView = ...

    class CursorAction(enum.Enum):
        MoveUp: QAbstractItemView = ...
        MoveDown: QAbstractItemView = ...
        MoveLeft: QAbstractItemView = ...
        MoveRight: QAbstractItemView = ...
        MoveHome: QAbstractItemView = ...
        MoveEnd: QAbstractItemView = ...
        MovePageUp: QAbstractItemView = ...
        MovePageDown: QAbstractItemView = ...
        MoveNext: QAbstractItemView = ...
        MovePrevious: QAbstractItemView = ...

    class SelectionMode(enum.Enum):
        NoSelection: QAbstractItemView = ...
        SingleSelection: QAbstractItemView = ...
        MultiSelection: QAbstractItemView = ...
        ExtendedSelection: QAbstractItemView = ...
        ContiguousSelection: QAbstractItemView = ...

    class SelectionBehavior(enum.Enum):
        SelectItems: QAbstractItemView = ...
        SelectRows: QAbstractItemView = ...
        SelectColumns: QAbstractItemView = ...

    class ScrollMode(enum.Enum):
        ScrollPerItem: QAbstractItemView = ...
        ScrollPerPixel: QAbstractItemView = ...

    class ScrollHint(enum.Enum):
        EnsureVisible: QAbstractItemView = ...
        PositionAtTop: QAbstractItemView = ...
        PositionAtBottom: QAbstractItemView = ...
        PositionAtCenter: QAbstractItemView = ...

    class EditTrigger(enum.Flag):
        NoEditTriggers: QAbstractItemView = ...
        CurrentChanged: QAbstractItemView = ...
        DoubleClicked: QAbstractItemView = ...
        SelectedClicked: QAbstractItemView = ...
        EditKeyPressed: QAbstractItemView = ...
        AnyKeyPressed: QAbstractItemView = ...
        AllEditTriggers: QAbstractItemView = ...

    class DragDropMode(enum.Enum):
        NoDragDrop: QAbstractItemView = ...
        DragOnly: QAbstractItemView = ...
        DropOnly: QAbstractItemView = ...
        DragDrop: QAbstractItemView = ...
        InternalMove: QAbstractItemView = ...

    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#QAbstractItemView

        **QAbstractItemView::QAbstractItemView(QWidget * parent = nullptr)**

        Constructs an abstract item view with the given **parent**.
        """
        ...

    def initViewItemOption(self, option: "QStyleOptionViewItem") -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#initViewItemOption

        **[virtual protected, since 6.0] void
        QAbstractItemView::initViewItemOption(QStyleOptionViewItem * option )
        const**

        Initialize the **option** structure with the view's palette, font,
        state, alignments etc.

        **Note:** Implementations of this methods should check the **version**
        of the structure received, populate all members the implementation is
        familiar with, and set the version member to the one supported by the
        implementation before returning.

        This function was introduced in Qt 6.0.
        """
        ...

    def isPersistentEditorOpen(self, index: QtCore.QModelIndex) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#isPersistentEditorOpen

        **[since 5.10] bool QAbstractItemView::isPersistentEditorOpen(const
        QModelIndex & index ) const**

        Returns whether a persistent editor is open for the item at index
        **index**.

        This function was introduced in Qt 5.10.

        **See also** **openPersistentEditor** () and **closePersistentEditor**
        ().
        """
        ...

    def resetHorizontalScrollMode(self) -> None:
        ...

    def resetVerticalScrollMode(self) -> None:
        ...

    def defaultDropAction(self) -> QtCore.Qt.DropAction:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#defaultDropAction-prop

        **defaultDropAction : Qt::DropAction**

        This property holds the drop action that will be used by default in
        QAbstractItemView::drag()

        If the property is not set, the drop action is CopyAction when the
        supported actions support CopyAction.

        **Access functions:**

        Qt::DropAction **defaultDropAction** () const
        void
        **setDefaultDropAction** (Qt::DropAction **dropAction** )

        **See also** **showDropIndicator**  and **dragDropOverwriteMode** .
        """
        ...

    def setDefaultDropAction(self, dropAction: QtCore.Qt.DropAction) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#defaultDropAction-prop

        **defaultDropAction : Qt::DropAction**

        This property holds the drop action that will be used by default in
        QAbstractItemView::drag()

        If the property is not set, the drop action is CopyAction when the
        supported actions support CopyAction.

        **Access functions:**

        Qt::DropAction **defaultDropAction** () const
        void
        **setDefaultDropAction** (Qt::DropAction **dropAction** )

        **See also** **showDropIndicator**  and **dragDropOverwriteMode** .
        """
        ...

    def eventFilter(self, object: QtCore.QObject, event: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#eventFilter

        **[override virtual protected] bool
        QAbstractItemView::eventFilter(QObject * object , QEvent * event )**

        Reimplements: **QObject::eventFilter** (QObject *watched, QEvent
        *event).
        """
        ...

    def viewportSizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#viewportSizeHint

        **[override virtual protected, since 5.2] QSize
        QAbstractItemView::viewportSizeHint() const**

        Reimplements: **QAbstractScrollArea::viewportSizeHint() const** .

        This function was introduced in Qt 5.2.
        """
        ...

    def inputMethodEvent(self, event: QtGui.QInputMethodEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#inputMethodEvent

        **[override virtual protected] void
        QAbstractItemView::inputMethodEvent(QInputMethodEvent * event )**

        Reimplements: **QWidget::inputMethodEvent** (QInputMethodEvent *event).
        """
        ...

    def focusNextPrevChild(self, next: bool) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#focusNextPrevChild

        **[override virtual protected] bool
        QAbstractItemView::focusNextPrevChild(bool next )**

        Reimplements: **QWidget::focusNextPrevChild** (bool next).
        """
        ...

    def autoScrollMargin(self) -> int:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#autoScrollMargin-prop

        **autoScrollMargin : int**

        This property holds the size of the area when auto scrolling is
        triggered

        This property controls the size of the area at the edge of the viewport
        that triggers autoscrolling. The default value is 16 pixels.

        **Access functions:**

        int **autoScrollMargin** () const
        void **setAutoScrollMargin** (int
        **margin** )
        """
        ...

    def setAutoScrollMargin(self, margin: int) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#autoScrollMargin-prop

        **autoScrollMargin : int**

        This property holds the size of the area when auto scrolling is
        triggered

        This property controls the size of the area at the edge of the viewport
        that triggers autoscrolling. The default value is 16 pixels.

        **Access functions:**

        int **autoScrollMargin** () const
        void **setAutoScrollMargin** (int
        **margin** )
        """
        ...

    def inputMethodQuery(self, query: QtCore.Qt.InputMethodQuery) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#inputMethodQuery

        **[override virtual] QVariant
        QAbstractItemView::inputMethodQuery(Qt::InputMethodQuery query ) const**

        Reimplements: **QWidget::inputMethodQuery(Qt::InputMethodQuery query)
        const** .
        """
        ...

    def itemDelegateForIndex(self, index: QtCore.QModelIndex) -> QAbstractItemDelegate:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#itemDelegateForIndex

        **[virtual, since 6.0] QAbstractItemDelegate
        *QAbstractItemView::itemDelegateForIndex(const QModelIndex & index )
        const**

        Returns the item delegate used by this view and model for the given
        **index**.

        This function was introduced in Qt 6.0.

        **See also** **setItemDelegate** (), **setItemDelegateForRow** (), and
        **setItemDelegateForColumn** ().
        """
        ...

    def itemDelegateForColumn(self, column: int) -> QAbstractItemDelegate:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#itemDelegateForColumn

        **QAbstractItemDelegate *QAbstractItemView::itemDelegateForColumn(int
        column ) const**

        Returns the item delegate used by this view and model for the given
        **column**. You can call **itemDelegate** () to get a pointer to the
        current delegate for a given index.

        **See also** **setItemDelegateForColumn** (), **itemDelegateForRow** (),
        and **itemDelegate** ().
        """
        ...

    def setItemDelegateForColumn(
        self, column: int, delegate: QAbstractItemDelegate
    ) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#setItemDelegateForColumn

        **void QAbstractItemView::setItemDelegateForColumn(int column ,
        QAbstractItemDelegate * delegate )**

        Sets the given item **delegate** used by this view and model for the
        given **column**. All items on **column** will be drawn and managed by
        **delegate** instead of using the default delegate (i.e.,
        **itemDelegate** ()).

        Any existing column delegate for **column** will be removed, but not
        deleted. **QAbstractItemView**  does not take ownership of **delegate**.

        **Note:** If a delegate has been assigned to both a row and a column,
        the row delegate will take precedence and manage the intersecting cell
        index.

        **Warning:** You should not share the same instance of a delegate
        between views. Doing so can cause incorrect or unintuitive editing
        behavior since each view connected to a given delegate may receive the
        **closeEditor** () signal, and attempt to access, modify or close an
        editor that has already been closed.

        **See also** **itemDelegateForColumn** (), **setItemDelegateForRow** (),
        and **itemDelegate** ().
        """
        ...

    def itemDelegateForRow(self, row: int) -> QAbstractItemDelegate:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#itemDelegateForRow

        **QAbstractItemDelegate *QAbstractItemView::itemDelegateForRow(int row )
        const**

        Returns the item delegate used by this view and model for the given
        **row** , or `nullptr` if no delegate has been assigned. You can call
        **itemDelegate** () to get a pointer to the current delegate for a given
        index.

        **See also** **setItemDelegateForRow** (), **itemDelegateForColumn** (),
        and **setItemDelegate** ().
        """
        ...

    def setItemDelegateForRow(self, row: int, delegate: QAbstractItemDelegate) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#setItemDelegateForRow

        **void QAbstractItemView::setItemDelegateForRow(int row ,
        QAbstractItemDelegate * delegate )**

        Sets the given item **delegate** used by this view and model for the
        given **row**. All items on **row** will be drawn and managed by
        **delegate** instead of using the default delegate (i.e.,
        **itemDelegate** ()).

        Any existing row delegate for **row** will be removed, but not deleted.
        **QAbstractItemView**  does not take ownership of **delegate**.

        **Note:** If a delegate has been assigned to both a row and a column,
        the row delegate (i.e., this delegate) will take precedence and manage
        the intersecting cell index.

        **Warning:** You should not share the same instance of a delegate
        between views. Doing so can cause incorrect or unintuitive editing
        behavior since each view connected to a given delegate may receive the
        **closeEditor** () signal, and attempt to access, modify or close an
        editor that has already been closed.

        **See also** **itemDelegateForRow** (), **setItemDelegateForColumn** (),
        and **itemDelegate** ().
        """
        ...

    def dragDropMode(self) -> "QAbstractItemView.DragDropMode":
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#dragDropMode-prop

        **dragDropMode : DragDropMode**

        This property holds the drag and drop event the view will act upon

        **Access functions:**

        QAbstractItemView::DragDropMode **dragDropMode** () const
        void
        **setDragDropMode** (QAbstractItemView::DragDropMode **behavior** )

        **See also** **showDropIndicator**  and **dragDropOverwriteMode** .
        """
        ...

    def setDragDropMode(self, behavior: "QAbstractItemView.DragDropMode") -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#dragDropMode-prop

        **dragDropMode : DragDropMode**

        This property holds the drag and drop event the view will act upon

        **Access functions:**

        QAbstractItemView::DragDropMode **dragDropMode** () const
        void
        **setDragDropMode** (QAbstractItemView::DragDropMode **behavior** )

        **See also** **showDropIndicator**  and **dragDropOverwriteMode** .
        """
        ...

    def dragDropOverwriteMode(self) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#dragDropOverwriteMode-prop

        **dragDropOverwriteMode : bool**

        This property holds the view's drag and drop behavior

        If its value is `true`, the selected data will overwrite the existing
        item data when dropped, while moving the data will clear the item. If
        its value is `false`, the selected data will be inserted as a new item
        when the data is dropped. When the data is moved, the item is removed as
        well.

        The default value is `false`, as in the **QListView**  and **QTreeView**
        subclasses. In the **QTableView**  subclass, on the other hand, the
        property has been set to `true`.

        Note: This is not intended to prevent overwriting of items. The model's
        implementation of flags() should do that by not returning
        **Qt::ItemIsDropEnabled** .

        **Access functions:**

        bool **dragDropOverwriteMode** () const
        void
        **setDragDropOverwriteMode** (bool **overwrite** )

        **See also** **dragDropMode** .
        """
        ...

    def setDragDropOverwriteMode(self, overwrite: bool) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#dragDropOverwriteMode-prop

        **dragDropOverwriteMode : bool**

        This property holds the view's drag and drop behavior

        If its value is `true`, the selected data will overwrite the existing
        item data when dropped, while moving the data will clear the item. If
        its value is `false`, the selected data will be inserted as a new item
        when the data is dropped. When the data is moved, the item is removed as
        well.

        The default value is `false`, as in the **QListView**  and **QTreeView**
        subclasses. In the **QTableView**  subclass, on the other hand, the
        property has been set to `true`.

        Note: This is not intended to prevent overwriting of items. The model's
        implementation of flags() should do that by not returning
        **Qt::ItemIsDropEnabled** .

        **Access functions:**

        bool **dragDropOverwriteMode** () const
        void
        **setDragDropOverwriteMode** (bool **overwrite** )

        **See also** **dragDropMode** .
        """
        ...

    def horizontalScrollMode(self) -> "QAbstractItemView.ScrollMode":
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#horizontalScrollMode-prop

        **horizontalScrollMode : ScrollMode**

        how the view scrolls its contents in the horizontal direction

        This property controls how the view scroll its contents horizontally.
        Scrolling can be done either per pixel or per item. Its default value
        comes from the style via the **QStyle::SH_ItemView_ScrollMode**  style
        hint.

        **Access functions:**

        QAbstractItemView::ScrollMode **horizontalScrollMode** () const
        void
        **setHorizontalScrollMode** (QAbstractItemView::ScrollMode **mode** )
        void **resetHorizontalScrollMode** ()
        """
        ...

    def setHorizontalScrollMode(self, mode: "QAbstractItemView.ScrollMode") -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#horizontalScrollMode-prop

        **horizontalScrollMode : ScrollMode**

        how the view scrolls its contents in the horizontal direction

        This property controls how the view scroll its contents horizontally.
        Scrolling can be done either per pixel or per item. Its default value
        comes from the style via the **QStyle::SH_ItemView_ScrollMode**  style
        hint.

        **Access functions:**

        QAbstractItemView::ScrollMode **horizontalScrollMode** () const
        void
        **setHorizontalScrollMode** (QAbstractItemView::ScrollMode **mode** )
        void **resetHorizontalScrollMode** ()
        """
        ...

    def verticalScrollMode(self) -> "QAbstractItemView.ScrollMode":
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#verticalScrollMode-prop

        **verticalScrollMode : ScrollMode**

        how the view scrolls its contents in the vertical direction

        This property controls how the view scroll its contents vertically.
        Scrolling can be done either per pixel or per item. Its default value
        comes from the style via the **QStyle::SH_ItemView_ScrollMode**  style
        hint.

        **Access functions:**

        QAbstractItemView::ScrollMode **verticalScrollMode** () const
        void
        **setVerticalScrollMode** (QAbstractItemView::ScrollMode **mode** )
        void **resetVerticalScrollMode** ()

        **Member Function Documentation**
        """
        ...

    def setVerticalScrollMode(self, mode: "QAbstractItemView.ScrollMode") -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#verticalScrollMode-prop

        **verticalScrollMode : ScrollMode**

        how the view scrolls its contents in the vertical direction

        This property controls how the view scroll its contents vertically.
        Scrolling can be done either per pixel or per item. Its default value
        comes from the style via the **QStyle::SH_ItemView_ScrollMode**  style
        hint.

        **Access functions:**

        QAbstractItemView::ScrollMode **verticalScrollMode** () const
        void
        **setVerticalScrollMode** (QAbstractItemView::ScrollMode **mode** )
        void **resetVerticalScrollMode** ()

        **Member Function Documentation**
        """
        ...

    def dropIndicatorPosition(self) -> "QAbstractItemView.DropIndicatorPosition":
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#dropIndicatorPosition

        **[protected] QAbstractItemView::DropIndicatorPosition
        QAbstractItemView::dropIndicatorPosition() const**

        Returns the position of the drop indicator in relation to the closest
        item.
        """
        ...

    def timerEvent(self, e: QtCore.QTimerEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#timerEvent

        **[override virtual protected] void
        QAbstractItemView::timerEvent(QTimerEvent * event )**

        Reimplements: **QObject::timerEvent** (QTimerEvent *event).

        This function is called with the given **event** when a timer event is
        sent to the widget.

        **See also** **QObject::timerEvent** ().
        """
        ...

    def resizeEvent(self, e: QtGui.QResizeEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#resizeEvent

        **[override virtual protected] void
        QAbstractItemView::resizeEvent(QResizeEvent * event )**

        Reimplements: **QAbstractScrollArea::resizeEvent** (QResizeEvent
        *event).

        This function is called with the given **event** when a resize event is
        sent to the widget.

        **See also** **QWidget::resizeEvent** ().
        """
        ...

    def keyPressEvent(self, e: QtGui.QKeyEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#keyPressEvent

        **[override virtual protected] void
        QAbstractItemView::keyPressEvent(QKeyEvent * event )**

        Reimplements: **QAbstractScrollArea::keyPressEvent** (QKeyEvent *e).

        This function is called with the given **event** when a key event is
        sent to the widget. The default implementation handles basic cursor
        movement, e.g. Up, Down, Left, Right, Home, PageUp, and PageDown; the
        **activated** () signal is emitted if the current index is valid and the
        activation key is pressed (e.g. Enter or Return, depending on the
        platform). This function is where editing is initiated by key press,
        e.g. if F2 is pressed.

        **See also** **edit** (), **moveCursor** (), **keyboardSearch** (), and
        **tabKeyNavigation** .
        """
        ...

    def focusOutEvent(self, e: QtGui.QFocusEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#focusOutEvent

        **[override virtual protected] void
        QAbstractItemView::focusOutEvent(QFocusEvent * event )**

        Reimplements: **QWidget::focusOutEvent** (QFocusEvent *event).

        This function is called with the given **event** when the widget loses
        the focus. By default, the event is ignored.

        **See also** **clearFocus** () and **focusInEvent** ().
        """
        ...

    def focusInEvent(self, e: QtGui.QFocusEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#focusInEvent

        **[override virtual protected] void
        QAbstractItemView::focusInEvent(QFocusEvent * event )**

        Reimplements: **QWidget::focusInEvent** (QFocusEvent *event).

        This function is called with the given **event** when the widget obtains
        the focus. By default, the event is ignored.

        **See also** **setFocus** () and **focusOutEvent** ().
        """
        ...

    def dropEvent(self, e: QtGui.QDropEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#dropEvent

        **[override virtual protected] void
        QAbstractItemView::dropEvent(QDropEvent * event )**

        Reimplements: **QAbstractScrollArea::dropEvent** (QDropEvent *event).

        This function is called with the given **event** when a drop event
        occurs over the widget. If the model accepts the even position the drop
        event is accepted; otherwise it is ignored.

        **See also** **startDrag** ().
        """
        ...

    def dragLeaveEvent(self, e: QtGui.QDragLeaveEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#dragLeaveEvent

        **[override virtual protected] void
        QAbstractItemView::dragLeaveEvent(QDragLeaveEvent * event )**

        Reimplements: **QAbstractScrollArea::dragLeaveEvent** (QDragLeaveEvent
        *event).

        This function is called when the item being dragged leaves the view. The
        **event** describes the state of the drag and drop operation.
        """
        ...

    def dragMoveEvent(self, e: QtGui.QDragMoveEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#dragMoveEvent

        **[override virtual protected] void
        QAbstractItemView::dragMoveEvent(QDragMoveEvent * event )**

        Reimplements: **QAbstractScrollArea::dragMoveEvent** (QDragMoveEvent
        *event).

        This function is called continuously with the given **event** during a
        drag and drop operation over the widget. It can cause the view to scroll
        if, for example, the user drags a selection to view's right or bottom
        edge. In this case, the event will be accepted; otherwise it will be
        ignored.

        **See also** **dropEvent** () and **startDrag** ().
        """
        ...

    def dragEnterEvent(self, e: QtGui.QDragEnterEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#dragEnterEvent

        **[override virtual protected] void
        QAbstractItemView::dragEnterEvent(QDragEnterEvent * event )**

        Reimplements: **QAbstractScrollArea::dragEnterEvent** (QDragEnterEvent
        *event).

        This function is called with the given **event** when a drag and drop
        operation enters the widget. If the drag is over a valid dropping place
        (e.g. over an item that accepts drops), the event is accepted; otherwise
        it is ignored.

        **See also** **dropEvent** () and **startDrag** ().
        """
        ...

    def mouseDoubleClickEvent(self, e: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#mouseDoubleClickEvent

        **[override virtual protected] void
        QAbstractItemView::mouseDoubleClickEvent(QMouseEvent * event )**

        Reimplements: **QAbstractScrollArea::mouseDoubleClickEvent**
        (QMouseEvent *e).

        This function is called with the given **event** when a mouse button is
        double clicked inside the widget. If the double-click is on a valid item
        it emits the **doubleClicked** () signal and calls **edit** () on the
        item.
        """
        ...

    def mouseReleaseEvent(self, e: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#mouseReleaseEvent

        **[override virtual protected] void
        QAbstractItemView::mouseReleaseEvent(QMouseEvent * event )**

        Reimplements: **QAbstractScrollArea::mouseReleaseEvent** (QMouseEvent
        *e).

        This function is called with the given **event** when a mouse button is
        released, after a mouse press event on the widget. If a user presses the
        mouse inside your widget and then drags the mouse to another location
        before releasing the mouse button, your widget receives the release
        event. The function will emit the **clicked** () signal if an item was
        being pressed.
        """
        ...

    def mouseMoveEvent(self, e: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#mouseMoveEvent

        **[override virtual protected] void
        QAbstractItemView::mouseMoveEvent(QMouseEvent * event )**

        Reimplements: **QAbstractScrollArea::mouseMoveEvent** (QMouseEvent *e).

        This function is called with the given **event** when a mouse move event
        is sent to the widget. If a selection is in progress and new items are
        moved over the selection is extended; if a drag is in progress it is
        continued.
        """
        ...

    def mousePressEvent(self, e: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#mousePressEvent

        **[override virtual protected] void
        QAbstractItemView::mousePressEvent(QMouseEvent * event )**

        Reimplements: **QAbstractScrollArea::mousePressEvent** (QMouseEvent *e).

        This function is called with the given **event** when a mouse button is
        pressed while the cursor is inside the widget. If a valid item is
        pressed on it is made into the current item. This function emits the
        **pressed** () signal.
        """
        ...

    def viewportEvent(self, e: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#viewportEvent

        **[override virtual protected] bool
        QAbstractItemView::viewportEvent(QEvent * event )**

        Reimplements: **QAbstractScrollArea::viewportEvent** (QEvent *event).

        This function is used to handle tool tips, and What's This? mode, if the
        given **event** is a **QEvent::ToolTip** ,or a **QEvent::WhatsThis** .
        It passes all other events on to its base class viewportEvent() handler.

        Returns `true` if **event** has been recognized and processed;
        otherwise, returns `false`.
        """
        ...

    def event(self, event: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#event

        **[override virtual protected] bool QAbstractItemView::event(QEvent *
        event )**

        Reimplements: **QAbstractScrollArea::event** (QEvent *event).
        """
        ...

    def dirtyRegionOffset(self) -> QtCore.QPoint:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#dirtyRegionOffset

        **[protected] QPoint QAbstractItemView::dirtyRegionOffset() const**

        Returns the offset of the dirty regions in the view.

        If you use **scrollDirtyRegion** () and implement a **paintEvent** () in
        a subclass of **QAbstractItemView** , you should translate the area
        given by the paint event with the offset returned from this function.

        **See also** **scrollDirtyRegion** () and **setDirtyRegion** ().
        """
        ...

    def setDirtyRegion(self, region: QtGui.QRegion) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#setDirtyRegion

        **[protected] void QAbstractItemView::setDirtyRegion(const QRegion &
        region )**

        Marks the given **region** as dirty and schedules it to be updated. You
        only need to call this function if you are implementing your own view
        subclass.

        **See also** **scrollDirtyRegion** () and **dirtyRegionOffset** ().
        """
        ...

    def scrollDirtyRegion(self, dx: int, dy: int) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#scrollDirtyRegion

        **[protected] void QAbstractItemView::scrollDirtyRegion(int dx , int dy
        )**

        Prepares the view for scrolling by ( **dx** , **dy** ) pixels by moving
        the dirty regions in the opposite direction. You only need to call this
        function if you are implementing a scrolling viewport in your view
        subclass.

        If you implement **scrollContentsBy** () in a subclass of
        **QAbstractItemView** , call this function before you call
        **QWidget::scroll** () on the viewport. Alternatively, just call
        **update** ().

        **See also** **scrollContentsBy** (), **dirtyRegionOffset** (), and
        **setDirtyRegion** ().
        """
        ...

    def executeDelayedItemsLayout(self) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#executeDelayedItemsLayout

        **[protected] void QAbstractItemView::executeDelayedItemsLayout()**

        Executes the scheduled layouts without waiting for the event processing
        to begin.

        **See also** **scheduleDelayedItemsLayout** ().
        """
        ...

    def scheduleDelayedItemsLayout(self) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#scheduleDelayedItemsLayout

        **[protected] void QAbstractItemView::scheduleDelayedItemsLayout()**

        Schedules a layout of the items in the view to be executed when the
        event processing starts.

        Even if scheduleDelayedItemsLayout() is called multiple times before
        events are processed, the view will only do the layout once.

        **See also** **executeDelayedItemsLayout** ().
        """
        ...

    def setState(self, state: "QAbstractItemView.State") -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#setState

        **[protected] void QAbstractItemView::setState(QAbstractItemView::State
        state )**

        Sets the item view's state to the given **state**.

        **See also** **state** ().
        """
        ...

    def state(self) -> "QAbstractItemView.State":
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#state

        **[protected] QAbstractItemView::State QAbstractItemView::state()
        const**

        Returns the item view's state.

        **See also** **setState** ().
        """
        ...

    def startDrag(self, supportedActions: QtCore.Qt.DropAction) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#startDrag

        **[virtual protected] void QAbstractItemView::startDrag(Qt::DropActions
        supportedActions )**

        Starts a drag by calling drag->exec() using the given
        **supportedActions**.
        """
        ...

    def selectionCommand(
        self, index: QtCore.QModelIndex, event: typing.Optional[QtCore.QEvent] = ...
    ) -> QtCore.QItemSelectionModel.SelectionFlag:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#selectionCommand

        **[virtual protected] QItemSelectionModel::SelectionFlags
        QAbstractItemView::selectionCommand(const QModelIndex & index , const
        QEvent * event = nullptr) const**

        Returns the SelectionFlags to be used when updating a selection with to
        include the **index** specified. The **event** is a user input event,
        such as a mouse or keyboard event.

        Reimplement this function to define your own selection behavior.

        **See also** **setSelection** ().
        """
        ...

    def selectedIndexes(self) -> typing.List[QtCore.QModelIndex]:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#selectedIndexes

        **[virtual protected] QModelIndexList
        QAbstractItemView::selectedIndexes() const**

        This convenience function returns a list of all selected and non-hidden
        item indexes in the view. The list contains no duplicates, and is not
        sorted.

        **See also** **QItemSelectionModel::selectedIndexes** ().
        """
        ...

    def visualRegionForSelection(
        self, selection: QtCore.QItemSelection
    ) -> QtGui.QRegion:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#visualRegionForSelection

        **[pure virtual protected] QRegion
        QAbstractItemView::visualRegionForSelection(const QItemSelection &
        selection ) const**

        Returns the region from the viewport of the items in the given
        **selection**.

        In the base class this is a pure virtual function.

        **See also** **visualRect** () and **selectedIndexes** ().
        """
        ...

    def setSelection(
        self, rect: QtCore.QRect, command: QtCore.QItemSelectionModel.SelectionFlag
    ) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#setSelection

        **[pure virtual protected] void QAbstractItemView::setSelection(const
        QRect & rect , QItemSelectionModel::SelectionFlags flags )**

        Applies the selection **flags** to the items in or touched by the
        rectangle, **rect**.

        When implementing your own itemview setSelection should call
        **selectionModel** ()->select(selection, flags) where selection is
        either an empty **QModelIndex**  or a **QItemSelection**  that contains
        all items that are contained in **rect**.

        **See also** **selectionCommand** () and **selectedIndexes** ().
        """
        ...

    def isIndexHidden(self, index: QtCore.QModelIndex) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#isIndexHidden

        **[pure virtual protected] bool QAbstractItemView::isIndexHidden(const
        QModelIndex & index ) const**

        Returns `true` if the item referred to by the given **index** is hidden
        in the view, otherwise returns `false`.

        Hiding is a view specific feature. For example in **TableView**  a
        column can be marked as hidden or a row in the TreeView.

        In the base class this is a pure virtual function.
        """
        ...

    def verticalOffset(self) -> int:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#verticalOffset

        **[pure virtual protected] int QAbstractItemView::verticalOffset()
        const**

        Returns the vertical offset of the view.

        In the base class this is a pure virtual function.

        **See also** **horizontalOffset** ().
        """
        ...

    def horizontalOffset(self) -> int:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#horizontalOffset

        **[pure virtual protected] int QAbstractItemView::horizontalOffset()
        const**

        Returns the horizontal offset of the view.

        In the base class this is a pure virtual function.

        **See also** **verticalOffset** ().
        """
        ...

    def moveCursor(
        self,
        cursorAction: "QAbstractItemView.CursorAction",
        modifiers: QtCore.Qt.KeyboardModifier,
    ) -> QtCore.QModelIndex:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#moveCursor

        **[pure virtual protected] QModelIndex
        QAbstractItemView::moveCursor(QAbstractItemView::CursorAction
        cursorAction , Qt::KeyboardModifiers modifiers )**

        Returns a **QModelIndex**  object pointing to the next object in the
        view, based on the given **cursorAction** and keyboard modifiers
        specified by **modifiers**.

        In the base class this is a pure virtual function.
        """
        ...

    def editorDestroyed(self, editor: QtCore.QObject) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#editorDestroyed

        **[virtual protected slot] void
        QAbstractItemView::editorDestroyed(QObject * editor )**

        This function is called when the given **editor** has been destroyed.

        **See also** **closeEditor** ().
        """
        ...

    def commitData(self, editor: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#commitData

        **[virtual protected slot] void QAbstractItemView::commitData(QWidget *
        editor )**

        Commit the data in the **editor** to the model.

        **See also** **closeEditor** ().
        """
        ...

    def closeEditor(
        self, editor: QWidget, hint: QAbstractItemDelegate.EndEditHint
    ) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#closeEditor

        **[virtual protected slot] void QAbstractItemView::closeEditor(QWidget *
        editor , QAbstractItemDelegate::EndEditHint hint )**

        Closes the given **editor** , and releases it. The **hint** is used to
        specify how the view should respond to the end of the editing operation.
        For example, the hint may indicate that the next item in the view should
        be opened for editing.

        **See also** **edit** () and **commitData** ().
        """
        ...

    def horizontalScrollbarValueChanged(self, value: int) -> None:
        ...

    def verticalScrollbarValueChanged(self, value: int) -> None:
        ...

    def horizontalScrollbarAction(self, action: int) -> None:
        ...

    def verticalScrollbarAction(self, action: int) -> None:
        ...

    def updateGeometries(self) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#updateGeometries

        **[virtual protected slot] void QAbstractItemView::updateGeometries()**

        Updates the geometry of the child widgets of the view.
        """
        ...

    def updateEditorGeometries(self) -> None:
        ...

    def updateEditorData(self) -> None:
        ...

    def currentChanged(
        self, current: QtCore.QModelIndex, previous: QtCore.QModelIndex
    ) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#currentChanged

        **[virtual protected slot] void QAbstractItemView::currentChanged(const
        QModelIndex & current , const QModelIndex & previous )**

        This slot is called when a new item becomes the current item. The
        previous current item is specified by the **previous** index, and the
        new item by the **current** index.

        If you want to know about changes to items see the **dataChanged** ()
        signal.
        """
        ...

    def selectionChanged(
        self, selected: QtCore.QItemSelection, deselected: QtCore.QItemSelection
    ) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#selectionChanged

        **[virtual protected slot] void
        QAbstractItemView::selectionChanged(const QItemSelection & selected ,
        const QItemSelection & deselected )**

        This slot is called when the selection is changed. The previous
        selection (which may be empty), is specified by **deselected** , and the
        new selection by **selected**.

        **See also** **setSelection** ().
        """
        ...

    def rowsAboutToBeRemoved(
        self, parent: QtCore.QModelIndex, start: int, end: int
    ) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#rowsAboutToBeRemoved

        **[virtual protected slot] void
        QAbstractItemView::rowsAboutToBeRemoved(const QModelIndex & parent , int
        start , int end )**

        This slot is called when rows are about to be removed. The deleted rows
        are those under the given **parent** from **start** to **end**
        inclusive.

        **See also** **rowsInserted** ().
        """
        ...

    def rowsInserted(self, parent: QtCore.QModelIndex, start: int, end: int) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#rowsInserted

        **[virtual protected slot] void QAbstractItemView::rowsInserted(const
        QModelIndex & parent , int start , int end )**

        This slot is called when rows are inserted. The new rows are those under
        the given **parent** from **start** to **end** inclusive. The base class
        implementation calls fetchMore() on the model to check for more data.

        **See also** **rowsAboutToBeRemoved** ().
        """
        ...

    def dataChanged(
        self,
        topLeft: QtCore.QModelIndex,
        bottomRight: QtCore.QModelIndex,
        roles: typing.Iterable[int] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#dataChanged

        **[virtual protected slot] void QAbstractItemView::dataChanged(const
        QModelIndex & topLeft , const QModelIndex & bottomRight , const
        QList<int> & roles = QList<int>())**

        This slot is called when items with the given **roles** are changed in
        the model. The changed items are those from **topLeft** to
        **bottomRight** inclusive. If just one item is changed **topLeft** ==
        **bottomRight**.

        The **roles** which have been changed can either be an empty container
        (meaning everything has changed), or a non-empty container with the
        subset of roles which have changed.

        **Note:** : **Qt::ToolTipRole**  is not honored by dataChanged() in the
        views provided by Qt.
        """
        ...

    @typing.overload
    def update(self) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#update

        **[slot] void QAbstractItemView::update(const QModelIndex & index )**

        Updates the area occupied by the given **index**.
        """
        ...

    @typing.overload
    def update(self, index: QtCore.QModelIndex) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#update

        **[slot] void QAbstractItemView::update(const QModelIndex & index )**

        Updates the area occupied by the given **index**.
        """
        ...

    def scrollToBottom(self) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#scrollToBottom

        **[slot] void QAbstractItemView::scrollToBottom()**

        Scrolls the view to the bottom.

        **See also** **scrollTo** () and **scrollToTop** ().
        """
        ...

    def scrollToTop(self) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#scrollToTop

        **[slot] void QAbstractItemView::scrollToTop()**

        Scrolls the view to the top.

        **See also** **scrollTo** () and **scrollToBottom** ().
        """
        ...

    def setCurrentIndex(self, index: QtCore.QModelIndex) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#setCurrentIndex

        **[slot] void QAbstractItemView::setCurrentIndex(const QModelIndex &
        index )**

        Sets the current item to be the item at **index**.

        Unless the current selection mode is **NoSelection** , the item is also
        selected. Note that this function also updates the starting position for
        any new selections the user performs.

        To set an item as the current item without selecting it, call

        `selectionModel()->setCurrentIndex(index,
        QItemSelectionModel::NoUpdate);`

        **See also** **currentIndex** (), **currentChanged** (), and
        **selectionMode** .
        """
        ...

    def clearSelection(self) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#clearSelection

        **[slot] void QAbstractItemView::clearSelection()**

        Deselects all selected items. The current index will not be changed.

        **See also** **setSelection** () and **selectAll** ().
        """
        ...

    @typing.overload
    def edit(self, index: QtCore.QModelIndex) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#edit

        **[slot] void QAbstractItemView::edit(const QModelIndex & index )**

        Starts editing the item corresponding to the given **index** if it is
        editable.

        Note that this function does not change the current index. Since the
        current index defines the next and previous items to edit, users may
        find that keyboard navigation does not work as expected. To provide
        consistent navigation behavior, call **setCurrentIndex** () before this
        function with the same model index.

        **See also** **QModelIndex::flags** ().
        """
        ...

    @typing.overload
    def edit(
        self,
        index: QtCore.QModelIndex,
        trigger: "QAbstractItemView.EditTrigger",
        event: QtCore.QEvent,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#edit-1

        **[virtual protected] bool QAbstractItemView::edit(const QModelIndex &
        index , QAbstractItemView::EditTrigger trigger , QEvent * event )**

        Starts editing the item at **index** , creating an editor if necessary,
        and returns `true` if the view's **State**  is now **EditingState** ;
        otherwise returns `false`.

        The action that caused the editing process is described by **trigger** ,
        and the associated event is specified by **event**.

        Editing can be forced by specifying the **trigger** to be
        **QAbstractItemView::AllEditTriggers** .

        **See also** **closeEditor** ().
        """
        ...

    def selectAll(self) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#selectAll

        **[virtual slot] void QAbstractItemView::selectAll()**

        Selects all items in the view. This function will use the selection
        behavior set on the view when selecting.

        **See also** **setSelection** (), **selectedIndexes** (), and
        **clearSelection** ().
        """
        ...

    def setRootIndex(self, index: QtCore.QModelIndex) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#setRootIndex

        **[virtual slot] void QAbstractItemView::setRootIndex(const QModelIndex
        & index )**

        Sets the root item to the item at the given **index**.

        **See also** **rootIndex** ().
        """
        ...

    def reset(self) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#reset

        **[virtual slot] void QAbstractItemView::reset()**

        Reset the internal state of the view.

        **Warning:** This function will reset open editors, scroll bar
        positions, selections, etc. Existing changes will not be committed. If
        you would like to save your changes when resetting the view, you can
        reimplement this function, commit your changes, and then call the
        superclass' implementation.
        """
        ...

    def indexWidget(self, index: QtCore.QModelIndex) -> QWidget:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#indexWidget

        **QWidget *QAbstractItemView::indexWidget(const QModelIndex & index )
        const**

        Returns the widget for the item at the given **index**.

        **See also** **setIndexWidget** ().
        """
        ...

    def setIndexWidget(self, index: QtCore.QModelIndex, widget: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#setIndexWidget

        **void QAbstractItemView::setIndexWidget(const QModelIndex & index ,
        QWidget * widget )**

        Sets the given **widget** on the item at the given **index** , passing
        the ownership of the widget to the viewport.

        If **index** is invalid (e.g., if you pass the root index), this
        function will do nothing.

        The given **widget** 's **autoFillBackground**  property must be set to
        true, otherwise the widget's background will be transparent, showing
        both the model data and the item at the given **index**.

        If index widget A is replaced with index widget B, index widget A will
        be deleted. For example, in the code snippet below, the **QLineEdit**
        object will be deleted.

        setIndexWidget(index, new **QLineEdit** );
            ...
        setIndexWidget(index, new **QTextEdit** );

        This function should only be used to display static content within the
        visible area corresponding to an item of data. If you want to display
        custom dynamic content or implement a custom editor widget, subclass
        **QStyledItemDelegate**  instead.

        **See also** **indexWidget** () and **Delegate Classes** .
        """
        ...

    def closePersistentEditor(self, index: QtCore.QModelIndex) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#closePersistentEditor

        **void QAbstractItemView::closePersistentEditor(const QModelIndex &
        index )**

        Closes the persistent editor for the item at the given **index**.

        **See also** **openPersistentEditor** () and **isPersistentEditorOpen**
        ().
        """
        ...

    def openPersistentEditor(self, index: QtCore.QModelIndex) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#openPersistentEditor

        **void QAbstractItemView::openPersistentEditor(const QModelIndex & index
        )**

        Opens a persistent editor on the item at the given **index**. If no
        editor exists, the delegate will create a new editor.

        **See also** **closePersistentEditor** () and **isPersistentEditorOpen**
        ().
        """
        ...

    def sizeHintForColumn(self, column: int) -> int:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#sizeHintForColumn

        **[virtual] int QAbstractItemView::sizeHintForColumn(int column )
        const**

        Returns the width size hint for the specified **column** or -1 if there
        is no model.

        This function is used in views with a horizontal header to find the size
        hint for a header section based on the contents of the given **column**.

        **See also** **sizeHintForRow** ().
        """
        ...

    def sizeHintForRow(self, row: int) -> int:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#sizeHintForRow

        **[virtual] int QAbstractItemView::sizeHintForRow(int row ) const**

        Returns the height size hint for the specified **row** or -1 if there is
        no model.

        The returned height is calculated using the size hints of the given
        **row** 's items, i.e. the returned value is the maximum height among
        the items. Note that to control the height of a row, you must
        reimplement the **QAbstractItemDelegate::sizeHint** () function.

        This function is used in views with a vertical header to find the size
        hint for a header section based on the contents of the given **row**.

        **See also** **sizeHintForColumn** ().
        """
        ...

    def sizeHintForIndex(self, index: QtCore.QModelIndex) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#sizeHintForIndex

        **QSize QAbstractItemView::sizeHintForIndex(const QModelIndex & index )
        const**

        Returns the size hint for the item with the specified **index** or an
        invalid size for invalid indexes.

        **See also** **sizeHintForRow** () and **sizeHintForColumn** ().
        """
        ...

    def indexAt(self, p: QtCore.QPoint) -> QtCore.QModelIndex:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#indexAt

        **[pure virtual] QModelIndex QAbstractItemView::indexAt(const QPoint &
        point ) const**

        Returns the model index of the item at the viewport coordinates
        **point**.

        In the base class this is a pure virtual function.

        **See also** **visualRect** ().
        """
        ...

    def scrollTo(
        self, index: QtCore.QModelIndex, hint: "QAbstractItemView.ScrollHint" = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#scrollTo

        **[pure virtual] void QAbstractItemView::scrollTo(const QModelIndex &
        index , QAbstractItemView::ScrollHint hint = EnsureVisible)**

        Scrolls the view if necessary to ensure that the item at **index** is
        visible. The view will try to position the item according to the given
        **hint**.

        In the base class this is a pure virtual function.
        """
        ...

    def visualRect(self, index: QtCore.QModelIndex) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#visualRect

        **[pure virtual] QRect QAbstractItemView::visualRect(const QModelIndex &
        index ) const**

        Returns the rectangle on the viewport occupied by the item at **index**.

        If your item is displayed in several areas then visualRect should return
        the primary area that contains index and not the complete area that
        index might encompasses, touch or cause drawing.

        In the base class this is a pure virtual function.

        **See also** **indexAt** () and **visualRegionForSelection** ().
        """
        ...

    def keyboardSearch(self, search: str) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#keyboardSearch

        **[virtual] void QAbstractItemView::keyboardSearch(const QString &
        search )**

        Moves to and selects the item best matching the string **search**. If no
        item is found nothing happens.

        In the default implementation, the search is reset if **search** is
        empty, or the time interval since the last search has exceeded
        **QApplication::keyboardInputInterval** ().
        """
        ...

    def textElideMode(self) -> QtCore.Qt.TextElideMode:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#textElideMode-prop

        **textElideMode : Qt::TextElideMode**

        This property holds the position of the "..." in elided text.

        The default value for all item views is **Qt::ElideRight** .

        **Access functions:**

        Qt::TextElideMode **textElideMode** () const
        void **setTextElideMode**
        (Qt::TextElideMode **mode** )
        """
        ...

    def setTextElideMode(self, mode: QtCore.Qt.TextElideMode) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#textElideMode-prop

        **textElideMode : Qt::TextElideMode**

        This property holds the position of the "..." in elided text.

        The default value for all item views is **Qt::ElideRight** .

        **Access functions:**

        Qt::TextElideMode **textElideMode** () const
        void **setTextElideMode**
        (Qt::TextElideMode **mode** )
        """
        ...

    def iconSize(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#iconSize-prop

        **iconSize : QSize**

        This property holds the size of items' icons

        Setting this property when the view is visible will cause the items to
        be laid out again.

        **Access functions:**

        QSize **iconSize** () const
        void **setIconSize** (const QSize &
        **size** )

        **Notifier signal:**

        void **iconSizeChanged** (const QSize & **size** )
        """
        ...

    def setIconSize(self, size: QtCore.QSize) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#iconSize-prop

        **iconSize : QSize**

        This property holds the size of items' icons

        Setting this property when the view is visible will cause the items to
        be laid out again.

        **Access functions:**

        QSize **iconSize** () const
        void **setIconSize** (const QSize &
        **size** )

        **Notifier signal:**

        void **iconSizeChanged** (const QSize & **size** )
        """
        ...

    def alternatingRowColors(self) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#alternatingRowColors-prop

        **alternatingRowColors : bool**

        This property holds whether to draw the background using alternating
        colors

        If this property is `true`, the item background will be drawn using
        **QPalette::Base**  and **QPalette::AlternateBase** ; otherwise the
        background will be drawn using the **QPalette::Base**  color.

        By default, this property is `false`.

        **Access functions:**

        bool **alternatingRowColors** () const
        void
        **setAlternatingRowColors** (bool **enable** )
        """
        ...

    def setAlternatingRowColors(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#alternatingRowColors-prop

        **alternatingRowColors : bool**

        This property holds whether to draw the background using alternating
        colors

        If this property is `true`, the item background will be drawn using
        **QPalette::Base**  and **QPalette::AlternateBase** ; otherwise the
        background will be drawn using the **QPalette::Base**  color.

        By default, this property is `false`.

        **Access functions:**

        bool **alternatingRowColors** () const
        void
        **setAlternatingRowColors** (bool **enable** )
        """
        ...

    def dragEnabled(self) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#dragEnabled-prop

        **dragEnabled : bool**

        This property holds whether the view supports dragging of its own items

        **Access functions:**

        bool **dragEnabled** () const
        void **setDragEnabled** (bool **enable**
        )

        **See also** **showDropIndicator** , **DragDropMode** ,
        **dragDropOverwriteMode** , and **acceptDrops** .
        """
        ...

    def setDragEnabled(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#dragEnabled-prop

        **dragEnabled : bool**

        This property holds whether the view supports dragging of its own items

        **Access functions:**

        bool **dragEnabled** () const
        void **setDragEnabled** (bool **enable**
        )

        **See also** **showDropIndicator** , **DragDropMode** ,
        **dragDropOverwriteMode** , and **acceptDrops** .
        """
        ...

    def showDropIndicator(self) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#showDropIndicator-prop

        **showDropIndicator : bool**

        This property holds whether the drop indicator is shown when dragging
        items and dropping.

        **Access functions:**

        bool **showDropIndicator** () const
        void **setDropIndicatorShown**
        (bool **enable** )

        **See also** **dragEnabled** , **DragDropMode** ,
        **dragDropOverwriteMode** , and **acceptDrops** .
        """
        ...

    def setDropIndicatorShown(self, enable: bool) -> None:
        ...

    def tabKeyNavigation(self) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#tabKeyNavigation-prop

        **tabKeyNavigation : bool**

        This property holds whether item navigation with tab and backtab is
        enabled.

        **Access functions:**

        bool **tabKeyNavigation** () const
        void **setTabKeyNavigation** (bool
        **enable** )
        """
        ...

    def setTabKeyNavigation(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#tabKeyNavigation-prop

        **tabKeyNavigation : bool**

        This property holds whether item navigation with tab and backtab is
        enabled.

        **Access functions:**

        bool **tabKeyNavigation** () const
        void **setTabKeyNavigation** (bool
        **enable** )
        """
        ...

    def hasAutoScroll(self) -> bool:
        ...

    def setAutoScroll(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#autoScroll-prop

        **autoScroll : bool**

        This property holds whether autoscrolling in drag move events is enabled

        If this property is set to true (the default), the **QAbstractItemView**
        automatically scrolls the contents of the view if the user drags within
        16 pixels of the viewport edge. If the current item changes, then the
        view will scroll automatically to ensure that the current item is fully
        visible.

        This property only works if the viewport accepts drops. Autoscroll is
        switched off by setting this property to false.

        **Access functions:**

        bool **hasAutoScroll** () const
        void **setAutoScroll** (bool
        **enable** )
        """
        ...

    def editTriggers(self) -> "QAbstractItemView.EditTrigger":
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#editTriggers-prop

        **editTriggers : EditTriggers**

        This property holds which actions will initiate item editing

        This property is a selection of flags defined by **EditTrigger** ,
        combined using the OR operator. The view will only initiate the editing
        of an item if the action performed is set in this property.

        **Access functions:**

        QAbstractItemView::EditTriggers **editTriggers** () const
        void
        **setEditTriggers** (QAbstractItemView::EditTriggers **triggers** )
        """
        ...

    def setEditTriggers(self, triggers: "QAbstractItemView.EditTrigger") -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#editTriggers-prop

        **editTriggers : EditTriggers**

        This property holds which actions will initiate item editing

        This property is a selection of flags defined by **EditTrigger** ,
        combined using the OR operator. The view will only initiate the editing
        of an item if the action performed is set in this property.

        **Access functions:**

        QAbstractItemView::EditTriggers **editTriggers** () const
        void
        **setEditTriggers** (QAbstractItemView::EditTriggers **triggers** )
        """
        ...

    def rootIndex(self) -> QtCore.QModelIndex:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#rootIndex

        **QModelIndex QAbstractItemView::rootIndex() const**

        Returns the model index of the model's root item. The root item is the
        parent item to the view's toplevel items. The root can be invalid.

        **See also** **setRootIndex** ().
        """
        ...

    def currentIndex(self) -> QtCore.QModelIndex:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#currentIndex

        **QModelIndex QAbstractItemView::currentIndex() const**

        Returns the model index of the current item.

        **See also** **setCurrentIndex** ().
        """
        ...

    def selectionBehavior(self) -> "QAbstractItemView.SelectionBehavior":
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#selectionBehavior-prop

        **selectionBehavior : SelectionBehavior**

        This property holds which selection behavior the view uses

        This property holds whether selections are done in terms of single
        items, rows or columns.

        **Access functions:**

        QAbstractItemView::SelectionBehavior **selectionBehavior** () const
        void **setSelectionBehavior** (QAbstractItemView::SelectionBehavior
        **behavior** )

        **See also** **SelectionMode**  and **SelectionBehavior** .
        """
        ...

    def setSelectionBehavior(
        self, behavior: "QAbstractItemView.SelectionBehavior"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#selectionBehavior-prop

        **selectionBehavior : SelectionBehavior**

        This property holds which selection behavior the view uses

        This property holds whether selections are done in terms of single
        items, rows or columns.

        **Access functions:**

        QAbstractItemView::SelectionBehavior **selectionBehavior** () const
        void **setSelectionBehavior** (QAbstractItemView::SelectionBehavior
        **behavior** )

        **See also** **SelectionMode**  and **SelectionBehavior** .
        """
        ...

    def selectionMode(self) -> "QAbstractItemView.SelectionMode":
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#selectionMode-prop

        **selectionMode : SelectionMode**

        This property holds which selection mode the view operates in

        This property controls whether the user can select one or many items
        and, in many-item selections, whether the selection must be a continuous
        range of items.

        **Access functions:**

        QAbstractItemView::SelectionMode **selectionMode** () const
        void
        **setSelectionMode** (QAbstractItemView::SelectionMode **mode** )

        **See also** **SelectionMode**  and **SelectionBehavior** .
        """
        ...

    def setSelectionMode(self, mode: "QAbstractItemView.SelectionMode") -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#selectionMode-prop

        **selectionMode : SelectionMode**

        This property holds which selection mode the view operates in

        This property controls whether the user can select one or many items
        and, in many-item selections, whether the selection must be a continuous
        range of items.

        **Access functions:**

        QAbstractItemView::SelectionMode **selectionMode** () const
        void
        **setSelectionMode** (QAbstractItemView::SelectionMode **mode** )

        **See also** **SelectionMode**  and **SelectionBehavior** .
        """
        ...

    def itemDelegate(self) -> QAbstractItemDelegate:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#itemDelegate

        **QAbstractItemDelegate *QAbstractItemView::itemDelegate() const**

        Returns the item delegate used by this view and model. This is either
        one set with **setItemDelegate** (), or the default one.

        **See also** **setItemDelegate** ().
        """
        ...

    def setItemDelegate(self, delegate: QAbstractItemDelegate) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#setItemDelegate

        **void QAbstractItemView::setItemDelegate(QAbstractItemDelegate *
        delegate )**

        Sets the item delegate for this view and its model to **delegate**. This
        is useful if you want complete control over the editing and display of
        items.

        Any existing delegate will be removed, but not deleted.
        **QAbstractItemView**  does not take ownership of **delegate**.

        **Warning:** You should not share the same instance of a delegate
        between views. Doing so can cause incorrect or unintuitive editing
        behavior since each view connected to a given delegate may receive the
        **closeEditor** () signal, and attempt to access, modify or close an
        editor that has already been closed.

        **See also** **itemDelegate** ().
        """
        ...

    def selectionModel(self) -> QtCore.QItemSelectionModel:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#selectionModel

        **QItemSelectionModel *QAbstractItemView::selectionModel() const**

        Returns the current selection model.

        **See also** **setSelectionModel** () and **selectedIndexes** ().
        """
        ...

    def setSelectionModel(self, selectionModel: QtCore.QItemSelectionModel) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#setSelectionModel

        **[virtual] void
        QAbstractItemView::setSelectionModel(QItemSelectionModel *
        selectionModel )**

        Sets the current selection model to the given **selectionModel**.

        Note that, if you call **setModel** () after this function, the given
        **selectionModel** will be replaced by one created by the view.

        **Note:** It is up to the application to delete the old selection model
        if it is no longer needed; i.e., if it is not being used by other views.
        This will happen automatically when its parent object is deleted.
        However, if it does not have a parent, or if the parent is a long-lived
        object, it may be preferable to call its **deleteLater** () function to
        explicitly delete it.

        **See also** **selectionModel** (), **setModel** (), and
        **clearSelection** ().
        """
        ...

    def model(self) -> QtCore.QAbstractItemModel:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#model

        **QAbstractItemModel *QAbstractItemView::model() const**

        Returns the model that this view is presenting.

        **See also** **setModel** ().
        """
        ...

    def setModel(self, model: QtCore.QAbstractItemModel) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#setModel

        **[virtual] void QAbstractItemView::setModel(QAbstractItemModel * model
        )**

        Sets the **model** for the view to present.

        This function will create and set a new selection model, replacing any
        model that was previously set with **setSelectionModel** (). However,
        the old selection model will not be deleted as it may be shared between
        several views. We recommend that you delete the old selection model if
        it is no longer required. This is done with the following code:

        **QItemSelectionModel**  *m = view->selectionModel();
        view->setModel(new model);
            delete m;

        If both the old model and the old selection model do not have parents,
        or if their parents are long-lived objects, it may be preferable to call
        their **deleteLater** () functions to explicitly delete them.

        The view **does not** take ownership of the model unless it is the
        model's parent object because the model may be shared between many
        different views.

        **See also** **model** (), **selectionModel** (), and
        **setSelectionModel** ().
        """
        ...

    @property
    def activated(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#activated

        **[signal] void QAbstractItemView::activated(const QModelIndex & index
        )**

        This signal is emitted when the item specified by **index** is activated
        by the user. How to activate items depends on the platform; e.g., by
        single- or double-clicking the item, or by pressing the Return or Enter
        key when the item is current.

        **See also** **clicked** (), **doubleClicked** (), **entered** (), and
        **pressed** ().
        """
        ...

    @property
    def clicked(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#clicked

        **[signal] void QAbstractItemView::clicked(const QModelIndex & index )**

        This signal is emitted when a mouse button is left-clicked. The item the
        mouse was clicked on is specified by **index**. The signal is only
        emitted when the index is valid.

        **See also** **activated** (), **doubleClicked** (), **entered** (), and
        **pressed** ().
        """
        ...

    @property
    def doubleClicked(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#doubleClicked

        **[signal] void QAbstractItemView::doubleClicked(const QModelIndex &
        index )**

        This signal is emitted when a mouse button is double-clicked. The item
        the mouse was double-clicked on is specified by **index**. The signal is
        only emitted when the index is valid.

        **See also** **clicked** () and **activated** ().
        """
        ...

    @property
    def entered(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#entered

        **[signal] void QAbstractItemView::entered(const QModelIndex & index )**

        This signal is emitted when the mouse cursor enters the item specified
        by **index**. Mouse tracking needs to be enabled for this feature to
        work.

        **See also** **viewportEntered** (), **activated** (), **clicked** (),
        **doubleClicked** (), and **pressed** ().
        """
        ...

    @property
    def iconSizeChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def pressed(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#pressed

        **[signal] void QAbstractItemView::pressed(const QModelIndex & index )**

        This signal is emitted when a mouse button is pressed. The item the
        mouse was pressed on is specified by **index**. The signal is only
        emitted when the index is valid.

        Use the **QGuiApplication::mouseButtons** () function to get the state
        of the mouse buttons.

        **See also** **activated** (), **clicked** (), **doubleClicked** (), and
        **entered** ().
        """
        ...

    @property
    def viewportEntered(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qabstractitemview.html#viewportEntered

        **[signal] void QAbstractItemView::viewportEntered()**

        This signal is emitted when the mouse cursor enters the viewport. Mouse
        tracking needs to be enabled for this feature to work.

        **See also** **entered** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6.QtSensors import *


class QLightReading(QSensorReading):
    """
    https://doc.qt.io/qt-6/qlightreading.html

    **Detailed Description**

    **QLightReading Units**

    The light sensor returns the intensity of the light in lux.
    """

    def setLux(self, lux: float) -> None:
        """
        https://doc.qt.io/qt-6/qlightreading.html#setLux

        **void QLightReading::setLux(qreal lux )**

        Sets the light level to **lux**.

        **See also** **lux** ().
        """
        ...

    def lux(self) -> float:
        """
        https://doc.qt.io/qt-6/qlightreading.html#lux-prop

        **[read-only] lux : const qreal**

        This property holds the light level.

        Measured as lux.

        **Access functions:**

        qreal **lux** () const

        **See also** **QLightReading Units** .

        **Member Function Documentation**
        """
        ...
